%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% STRUCTURAL MLE COUNTERFACTUAL (Figure 3 and Panel B of Table A3)
%%% COUNTERFACTUAL OVER TIME (Figure A4)

%%% First run mainMLE.m and mainMLEmultdest.m to generate ML Estimates
%%% written into THETA_MLE.csv, THETA_MLEmd.csv, THETA_MLEmd_alt.csv
%%% See the bottom part of the code to generate Figure A4



clear all
close all
cd '/home/sjredding/himr-restud/matlab/brazil'
clc


%% ------ ESTIMATED PARAMETERS ------


%% load estimated parameters
THETA_MLE = csvread('THETA_MLE.csv');
THETA_MLEmd = csvread('THETA_MLEmd.csv');
THETA_MLEmd_alt = csvread('THETA_MLEmd_alt.csv');


%% indexes of the estimated parameters
% in all specifications
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v

% for single-destination specification
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f

% for multi-destination specification
imh1 = 6;   % mu_h1
imh2 = 7;   % mu_h2 (corresponds to increment mu_h2-mu_h1 in the paper)
imh3 = 8;   % mu_h3 (corresponds to increment mu_h3-mu_h2 in the paper)
imw1 = 9;   % mu_w1
imw2 = 10;  % mu_w2 (corresponds to increment mu_w2-mu_w1 in the paper)
imw3 = 11;  % mu_w3 (corresponds to increment mu_w3-mu_w2 in the paper)
ifx1 = 12;  % f_x1
ifx2 = 13;  % f_x2
ifx3 = 14;  % f_x3


%% load data to calculate average employment and wages for alpha_h and alpha_w:
t   = 1994-1986+1;      % baseline year 1994 for counterfactual
data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1994-fun.csv');
H = log(data(:,10));    % log employment
W = data(:,8);          % log wage (8 for FIRM FE PSI and 4 for MEAN LOG WAGE)
hbar = mean(H);         % average log employment 
wbar = mean(W);         % average log wage


%% --- Parameters in single-destination model
zt  = THETA_MLE(izt,t);
muh = THETA_MLE(imh,t);
muw = THETA_MLE(imw,t);
ru  = THETA_MLE(iru,t);
rv  = THETA_MLE(irv,t);
su  = THETA_MLE(isu,t);
sv  = THETA_MLE(isv,t);
fx  = THETA_MLE(ifx,t);
ah  = hbar - muh*(1-normcdf(fx,0,1));
aw  = wbar - muw*(1-normcdf(fx,0,1));


%% --- Parameters in multi-destination model Specification A
ztm1  = THETA_MLEmd(izt,t);
sum1  = THETA_MLEmd(isu,t);
svm1  = THETA_MLEmd(isv,t);
rum1  = THETA_MLEmd(iru,t);
rvm1  = THETA_MLEmd(irv,t);
mh1m1 = THETA_MLEmd(imh1,t);
mh2m1 = THETA_MLEmd(imh2,t);
mh3m1 = THETA_MLEmd(imh3,t);
mw1m1 = THETA_MLEmd(imw1,t);
mw2m1 = THETA_MLEmd(imw2,t);
mw3m1 = THETA_MLEmd(imw3,t);
f1m1  = THETA_MLEmd(ifx1,t);
f2m1  = f1m1 + THETA_MLEmd(ifx2,t);
f3m1  = f2m1 + THETA_MLEmd(ifx3,t);
ahm1  = hbar - mh1m1*(1-normcdf(f1m1,0,1)) - mh2m1*(1-normcdf(f2m1,0,1)) - mh3m1*(1-normcdf(f3m1,0,1));
awm1  = wbar - mw1m1*(1-normcdf(f1m1,0,1)) - mw2m1*(1-normcdf(f2m1,0,1)) - mw3m1*(1-normcdf(f3m1,0,1));


%% --- Parameters in multi-destination model Specification B
ztm2  = THETA_MLEmd_alt(izt,t);
sum2  = THETA_MLEmd_alt(isu,t);
svm2  = THETA_MLEmd_alt(isv,t);
rum2  = THETA_MLEmd_alt(iru,t);
rvm2  = THETA_MLEmd_alt(irv,t);
mh1m2 = THETA_MLEmd_alt(imh1,t);
mh2m2 = THETA_MLEmd_alt(imh2,t);
mh3m2 = THETA_MLEmd_alt(imh3,t);
mw1m2 = THETA_MLEmd_alt(imw1,t);
mw2m2 = THETA_MLEmd_alt(imw2,t);
mw3m2 = THETA_MLEmd_alt(imw3,t);
f1m2  = THETA_MLEmd_alt(ifx1,t);
f2m2  = f1m2 + THETA_MLEmd_alt(ifx2,t);
f3m2  = f2m2 + THETA_MLEmd_alt(ifx3,t);
ahm2 = hbar - mh1m2*(1-normcdf(f1m2,0,1)) - mh2m2*(1-normcdf(f2m2,0,1)) - mh3m2*(1-normcdf(f3m2,0,1));
awm2 = wbar - mw1m2*(1-normcdf(f1m2,0,1)) - mw2m2*(1-normcdf(f2m2,0,1)) - mw3m2*(1-normcdf(f3m2,0,1));




%% ------ CALIBRATED PARAMETERS ------

% denoted as in the paper:

beta = 3/4;
gamma = 1/2;
k = 4/3;
delta = k * (1 + muh/muw);
Gamma = 1 - beta*gamma - beta/delta*(1-gamma*k);
tau = 1.6;
% relative demand Ax/Ad:
RD = ( exp(muh+muw)^(Gamma/(1-beta)) - 1 ) * tau^(beta/(1-beta)) ;




%% ------ DATA GENERATING PROCESS ------
% generating model-simulated dataset of firm employment, wages, export status

% Number of draws (use 10M for precision and 100K for fast calculation)
N = 10000000;

% Shock draws for (u,v,z) across firms:
ZZZ = randn(N,3);


%% single-destination model

SIGMA = [su^2 0 ru*su; 
         0 sv^2 rv*sv;
         ru*su rv*sv 1];
     
DDD = (ZZZ*SIGMA^(1/2));
UU = DDD(:,1);      % u shock
VV = DDD(:,2);      % v shock
ZZ = DDD(:,3);      % z shock
OM = zt*UU+VV;      % omega = zeta*u+v

II = zeros(N,1);
II(ZZ>=fx) = 1;             % firm export status
HH = ah + muh*II + UU;      % firm log employment
WW = aw + muw*II + OM;      % firm log wages


%% multi-destination model A

SIGMAm1 = [sum1^2 0 rum1*sum1; 
         0 svm1^2 rvm1*svm1;
         rum1*sum1 rvm1*svm1 1];

DDDm1 = (ZZZ*SIGMAm1^(1/2));
UUm1 = DDDm1(:,1);      % u shock
VVm1 = DDDm1(:,2);      % v shock
ZZm1 = DDDm1(:,3);      % z shock
OMm1 = ztm1*UUm1+VVm1;  % omega = zeta*u + v

I1m1 = zeros(N,1);      
I1m1(ZZ>=f1m1) = 1;     % firm export status 1
I2m1 = zeros(N,1);      
I2m1(ZZ>=f2m1) = 1;     % firm export status 2
I3m1 = zeros(N,1);
I3m1(ZZ>=f3m1) = 1;     % firm export status 3
% firm log employment
HHm1 = ahm1 + mh1m1*I1m1 + mh2m1*I2m1 + mh3m1*I3m1 + UUm1;
% firm log wages
WWm1 = awm1 + mw1m1*I1m1 + mw2m1*I2m1 + mw3m1*I3m1 + OMm1;


%% multi-destination model B

SIGMAm2 = [sum2^2 0 rum2*sum2; 
         0 svm2^2 rvm2*svm2;
         rum2*sum2 rvm2*svm2 1];

DDDm2 = (ZZZ*SIGMAm2^(1/2));
UUm2 = DDDm2(:,1);      % u shock
VVm2 = DDDm2(:,2);      % v shock
ZZm2 = DDDm2(:,3);      % z shock
OMm2 = ztm2*UUm2+VVm2;  % omega=zeta*u+v

I1m2 = zeros(N,1);
I1m2(ZZ>=f1m2) = 1;     % firm export status 1
I2m2 = zeros(N,1);
I2m2(ZZ>=f2m2) = 1;     % firm export status 2
I3m2 = zeros(N,1);
I3m2(ZZ>=f3m2) = 1;     % firm export status 3
% firm log employment
HHm2 = ahm2 + mh1m2*I1m2 + mh2m2*I2m2 + mh3m2*I3m2 + UUm2;
% firm log wages
WWm2 = awm2 + mw1m2*I1m2 + mw2m2*I2m2 + mw3m2*I3m2 + OMm2;



%%  variance of log worker wages:

% single-destination model
% in counterfactual autarky:
VARAUT = mean(OM.^2 .* exp(UU))/mean(exp(UU)) - (mean(OM .* exp(UU))/mean(exp(UU)))^2 ;
% in estimated open-economy equilibrium:
VAROPEN = mean(WW.^2 .* exp(HH))/mean(exp(HH)) - (mean( (WW) .* exp(HH))/mean(exp(HH)))^2 ;
% relative standard deviation of log worker wages (relative to counterfactual autarky):
CF = sqrt(VAROPEN/VARAUT);
% exporter employment share in estimated open-economy equilibrium:
SHH = II'*exp(HH)/sum(exp(HH));


% multi-destination model A
% in counterfactual autarky:
VARAUTm1 = mean(OMm1.^2 .* exp(UUm1))/mean(exp(UUm1)) - (mean(OMm1 .* exp(UUm1))/mean(exp(UUm1)))^2 ;
% in estimated open-economy equilibrium:
VAROPENm1 = mean(WWm1.^2 .* exp(HHm1))/mean(exp(HHm1)) - (mean( (WWm1) .* exp(HHm1))/mean(exp(HHm1)))^2 ;
% relative standard deviation of log worker wages (relative to counterfactual autarky):
CFm1 = sqrt(VAROPENm1/VARAUTm1);
% exporter employment shares in estimated open-economy equilibrium:
SH1m1 = I1m1'*exp(HHm1)/sum(exp(HHm1));
SH2m1 = I2m1'*exp(HHm1)/sum(exp(HHm1));
SH3m1 = I3m1'*exp(HHm1)/sum(exp(HHm1));


% multi-destination model B
% in counterfactual autarky:
VARAUTm2 = mean(OMm2.^2 .* exp(UUm2))/mean(exp(UUm2)) - (mean(OMm2 .* exp(UUm2))/mean(exp(UUm2)))^2 ;
% in estimated open-economy equilibrium:
VAROPENm2 = mean(WWm2.^2 .* exp(HHm2))/mean(exp(HHm2)) - (mean( (WWm2) .* exp(HHm2))/mean(exp(HHm2)))^2 ;
% relative standard deviation of log worker wages (relative to counterfactual autarky):
CFm2 = sqrt(VAROPENm2/VARAUTm2);
% exporter employment shares in estimated open-economy equilibrium:
SH1m2 = I1m2'*exp(HHm2)/sum(exp(HHm2));
SH2m2 = I2m2'*exp(HHm2)/sum(exp(HHm2));
SH3m2 = I3m2'*exp(HHm2)/sum(exp(HHm2));




%% ---- Variable Trade Cost Counterfactual ----

DATA = [];
tic
for mm=0:.001:5;         % use step 0.001 for precision and 0.01 for fast calculation
    
    %% single-destination model
    % counterfactual values of mu_h, mu_w and f_x (see paper)
    muh0 = mm*muh;
    muw0 = mm*muw;
    fx0 = fx - (ru^2 + rv^2)/((1+zt)^2*su^2+sv^2) *( log(exp(muh0+muw0)-1) - log(exp(muh+muw)-1));
    
    % corresponding counterfactual export status, employment and wages of the firms
    II0 = zeros(N,1);
    II0(ZZ>=fx0) = 1;
    HH0 = ah + muh0*II0 + UU;
    WW0 = aw + muw0*II0 + OM;

    % variance of log worker wages in counterfactual open-economy equilibrium:
    VAROPEN0 = mean(WW0.^2 .* exp(HH0))/mean(exp(HH0)) - (mean( (WW0) .* exp(HH0))/mean(exp(HH0)))^2 ;
    % relative standard deviation of log worker wages in counterfactual equilibrium relative to counterfactual autarky:
    CF0 = sqrt(VAROPEN0/VARAUT);
    % exporter employment share in counterfactual open-economy equilibrium:
    SHH0 = II0'*exp(HH0)/sum(exp(HH0));

    
    %% multi-destination model Spec A
    % counterfactual values of mu_h, mu_w and f_x (see paper)
    mh1m10 = mm*mh1m1;
    mw1m10 = mm*mw1m1;
    mh2m10 = mm*mh2m1;
    mw2m10 = mm*mw2m1;
    mh3m10 = mm*mh3m1;
    mw3m10 = mm*mw3m1;
    f1m10 = f1m1 - (rum1^2 + rvm1^2)/((1+ztm1)^2*sum1^2+svm1^2) *( log(exp(mh1m10+mw1m10)-1) - log(exp(mh1m1+mw1m1)-1));
    f2m10 = f2m1 - (rum1^2 + rvm1^2)/((1+ztm1)^2*sum1^2+svm1^2) *( log(exp(mh1m10+mw1m10+mh2m10+mw2m10)-exp(mh1m10+mw1m10)) ...
        - log(exp(mh1m1+mw1m1+mh2m1+mw2m1)-exp(mh1m1+mw1m1)));
    f3m10 = f3m1 - (rum1^2 + rvm1^2)/((1+ztm1)^2*sum1^2+svm1^2) *( log(exp(mh1m10+mw1m10+mh2m10+mw2m10+mh3m10+mw3m10)-exp(mh1m10+mw1m10+mh2m10+mw2m10)) ...
        - log(exp(mh1m1+mw1m1+mh2m1+mw2m1+mh3m1+mw3m1)-exp(mh1m1+mw1m1+mh2m1+mw2m1)));
    
    % corresponding counterfactual export status, employment and wages of the firms
    I1m10 = zeros(N,1);
    I1m10(ZZ>=f1m10) = 1;
    I2m10 = zeros(N,1);
    I2m10(ZZ>=f2m10) = 1;
    I3m10 = zeros(N,1);
    I3m10(ZZ>=f3m10) = 1;
    HHm10 = ahm1 + mh1m10*I1m10 + mh2m10*I2m10 + mh3m10*I3m10 + UUm1;
    WWm10 = awm1 + mw1m10*I1m10 + mw2m10*I2m10 + mw3m10*I3m10 + OMm1;

    % variance of log worker wages in counterfactual open-economy equilibrium:
    VAROPENm10 = mean(WWm10.^2 .* exp(HHm10))/mean(exp(HHm10)) - (mean( (WWm10) .* exp(HHm10))/mean(exp(HHm10)))^2 ;
    % relative standard deviation of log worker wages in counterfactual equilibrium relative to counterfactual autarky:
    CFm10 = sqrt(VAROPENm10/VARAUTm1);
    % exporter employment share in counterfactual open-economy equilibrium:
    SH1m10 = I1m10'*exp(HHm10)/sum(exp(HHm10));
    SH2m10 = I2m10'*exp(HHm10)/sum(exp(HHm10));
    SH3m10 = I3m10'*exp(HHm10)/sum(exp(HHm10));
    
    
    %% multi-destination model Spec A
    % counterfactual values of mu_h, mu_w and f_x (see paper)    
    mh1m20 = mm*mh1m2;
    mw1m20 = mm*mw1m2;
    mh2m20 = mm*mh2m2;
    mw2m20 = mm*mw2m2;
    mh3m20 = mm*mh3m2;
    mw3m20 = mm*mw3m2;
    f1m20 = f1m2 - (rum2^2 + rvm2^2)/((1+ztm2)^2*sum2^2+svm2^2) *( log(exp(mh1m20+mw1m20)-1) - log(exp(mh1m2+mw1m2)-1));
    f2m20 = f2m2 - (rum2^2 + rvm2^2)/((1+ztm2)^2*sum2^2+svm2^2) *( log(exp(mh1m20+mw1m20+mh2m20+mw2m20)-exp(mh1m20+mw1m20)) ...
        - log(exp(mh1m2+mw1m2+mh2m2+mw2m2)-exp(mh1m2+mw1m2)));
    f3m20 = f3m2 - (rum2^2 + rvm2^2)/((1+ztm2)^2*sum2^2+svm2^2) *( log(exp(mh1m20+mw1m20+mh2m20+mw2m20+mh3m20+mw3m20)-exp(mh1m20+mw1m20+mh2m20+mw2m20)) ...
        - log(exp(mh1m2+mw1m2+mh2m2+mw2m2+mh3m2+mw3m2)-exp(mh1m2+mw1m2+mh2m2+mw2m2)));
    
    % corresponding counterfactual export status, employment and wages of the firms
    I1m20 = zeros(N,1);
    I1m20(ZZ>=f1m20) = 1;
    I2m20 = zeros(N,1);
    I2m20(ZZ>=f2m20) = 1;
    I3m20 = zeros(N,1);
    I3m20(ZZ>=f3m20) = 1;
    HHm20 = ahm2 + mh1m20*I1m20 + mh2m20*I2m20 + mh3m20*I3m20 + UUm2;
    WWm20 = awm2 + mw1m20*I1m20 + mw2m20*I2m20 + mw3m20*I3m20 + OMm2;

    % variance of log worker wages in counterfactual open-economy equilibrium:
    VAROPENm20 = mean(WWm20.^2 .* exp(HHm20))/mean(exp(HHm20)) - (mean( (WWm20) .* exp(HHm20))/mean(exp(HHm20)))^2 ;
    % relative standard deviation of log worker wages in counterfactual equilibrium relative to counterfactual autarky:
    CFm20 = sqrt(VAROPENm20/VARAUTm2);
    % exporter employment share in counterfactual open-economy equilibrium:
    SH1m20 = I1m20'*exp(HHm20)/sum(exp(HHm20));
    SH2m20 = I2m20'*exp(HHm20)/sum(exp(HHm20));
    SH3m20 = I3m20'*exp(HHm20)/sum(exp(HHm20));
    
    
    DATA = [DATA; [SHH0 CF0 SH1m10 SH2m10 SH3m10 CFm10 SH1m20 SH2m20 SH3m20 CFm20 ...
        mean([II0 I1m10 I2m10 I3m10 I1m20 I2m20 I3m20]) ]];
    
end
toc



%% ------ PLOT VARIABLE TRADE COST COUNTERFACTUALS ------
% Figure 3 in the paper (Panel B of Table A3 uses information from this figure)

figure(3)
plot([.2 .2],[1 1.25],'k:','linewidth',1)
hold on
area([SH1m1-.1+.00025 SH1m1],[1.25-.00025 1.25-.00025],1+.00025,'edgecolor','none','facecolor',[.85,.85,.85])
area([SH1m1 SH1m1+.1-.00025],[1.25-.00025 1.25-.00025],1+.00025,'edgecolor','none','facecolor',[.9,.9,.9])
for xt = 0.4:.2:.8
    plot([xt xt],[1 1.25],'k:','linewidth',1)
end
for yt = 1.05:.05:1.2
    plot([0 1],[yt yt],'k:','linewidth',1)
end
plot(DATA(:,1),max(DATA(:,2),1),'k','linewidth',1)
plot(DATA(:,3),max(DATA(:,6),1),'linewidth',2)
plot(DATA(:,7),max(DATA(:,10),1),'r--','linewidth',2)
plot(SH1m1,CFm1,'o','markersize',8,'linewidth',3)
plot(SH1m2,CFm2,'ro','markersize',8,'linewidth',3)
xlim([0 1])
ylim([1 1.25])
xlabel('Exporter employment share','FontSize',16,'interpreter','latex')
ylabel('Wage inequality (\% increase)','FontSize',16,'interpreter','latex')
set(gca,'FontSize',14)
set(gca,'xtick',[0:.2:1])
set(gca,'ytick',[1:.05:1.25])
set(gca,'yticklabel',[0:5:25])

print -depsc counterfactual_mult.eps





%% COUNTERFACTUAL OVER TIME
% % Run COUNTERFACTUALovertime.m to generate Figure A4
% COUNTERFACTUALovertime.m
