%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% STANDARD ERRORS FOR STRUCTURAL MAXIMUM LIKELIHOOD ESTRIMATES

%%% First run mainMLE.m to generate ML Estimates written into THETA_MLE.csv

clear all
close all
clc
cd '/home/sjredding/himr-restud/matlab/brazil'

global K iah iaw izt isu isv iru irv imh imw ifx X eps

%% ------ PARAMETERS ------
% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f
iah = 9;    % alpha_h
iaw = 10;   % alpha_w

eps=1e-10;  % precision

% Load Structural ML Estimates
THETA_MLE = csvread('THETA_MLE.csv');

K0 = size(THETA_MLE,1); % K0+2 is the total number of paramters (2 additional intercepts)
T = size(THETA_MLE,2);  % number of years for estimation

STERR=zeros(K0+2,4,T);    % matrix of standard errors for ML Estimates THETA_MLE

yr = 1986-1;            % initial year
for t = 1:T
    yr = yr + 1
    
    %% --- LOAD DATA X --- 
    if yr==1986;     data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1986-fun.csv');
    elseif yr==1987; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1987-fun.csv');
    elseif yr==1988; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1988-fun.csv');
    elseif yr==1989; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1989-fun.csv');
    elseif yr==1990; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1990-fun.csv');
    elseif yr==1991; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1991-fun.csv');
    elseif yr==1992; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1992-fun.csv');
    elseif yr==1993; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1993-fun.csv');
    elseif yr==1994; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1994-fun.csv');
    elseif yr==1995; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1995-fun.csv');
    elseif yr==1996; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1996-fun.csv');
    elseif yr==1997; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1997-fun.csv');
    elseif yr==1998; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1998-fun.csv');
    end
    %     Columns in firm-year data;

    % Column 1 : cnpj_radic; 
    % Column 2 : firm_subsibge; 
    % Column 3 : year; 
    % Column 4 : lwageyr;   
    % Column 5 : wageyr; 
    % Column 6 : reslwageyr; 
    % Column 7 : obslwageyr; 
    % Column 8 : felwageyr; 
    % Column 9 : indexp; 
    % Column 10 : employ; 
    % Column 11 : indimp; 
    % Column 12 : indexpusa; 
    % Column 13 : meso; 
    % Column 14 : state; 
    % Column 15 : lwageyrmeso; 
    % Column 16 : felwageyrmeso; 
    % Column 17 : lemploymeso;
    % Column 18 : indexpbin1; 
    % Column 19 : indexpbin2; 
    % Column 20 : indexpbin3; 
    % Column 21 : forworker;
    % Column 22 : nexpbin1; 
    % Column 23 : nexpbin2; 
    % Column 24 : nexpbin3;

    N = size(data,1);       % number of observations (firms)
    I = data(:,9);       % export status (dummy for exporter)
    H = log(data(:,10));  % log employment
    W = data(:,8);        % log wage (8 for FIRM FE PSI and 4 for MEAN LOG WAGE)
    X = [H W I];            % data matrix

    % Parameter vector
    Theta0 = THETA_MLE(:,t);                % estimated vector
    Theta = Theta0([1:imw-1 imw+1:K0],1);   % dismiss mu_w which is tied down by the structural constraint
    Theta = [Theta; mean(H-Theta0(imh)*I) ; mean(W-Theta0(imw)*I)];     % add intercepts
    Theta0 = [Theta0; mean(H-Theta0(imh)*I) ; mean(W-Theta0(imw)*I)];   % full vector, including mu_w
    K = size(Theta,1);
    
    
    %% Calculating standard errors
    tic
    Es=0;
    Ess=0;
    Vss=0;
    for j=1:N
        scorej = sj_c(Theta,X(j,:))';               % score (first derivative) of log-likelihood, see sj_c.m
        Es = Es + scorej;
        Ess = Ess + scorej*scorej';
        sprimej = reshape(ssj_c(Theta,X(j,:)),K,K); % hessian (second derivative) of log-likelihood, see ssj_c.m
        Vss = Vss + sprimej;                        
    end
    Es = Es/N;
    Ess = Ess/N;
    Vss = Vss/N;
    toc
    
    % Delta method for mu_w
    GM = eye(9);
    GM = [GM(:,1:8) zeros(9,1) GM(:,9)];
    GM(izt,9) = Theta0(imh,1);
    GM(imh,9) = Theta0(izt,1);
    
    % Standard errors
    Vml1 = GM'*inv(Ess)*GM/N;                   % score-based
    Vml2 = GM'*inv(-Vss)*GM/N;                  % hessian-based
    Vmls = GM'*inv(-Vss)*Ess*inv(-Vss)*GM/N;    % sandwich-form (default option in what follows)
    
    disp('standard errors: score, hessian, sandwich')
    STERR(:,:,t) = [Theta0 sqrt(diag(Vml1)) sqrt(diag(Vml2)) sqrt(diag(Vmls))];
    STERR(:,:,t)
    
        
end


% Save standard errors:
dlmwrite('STERR.csv',STERR,'precision','%14.6f','newline','pc');


%% TABLE4: Parameter estimates with standard errors for 1994
disp('Table 4: Parameter estimates')
display('imh imw iru irv ifx');
disp([STERR([imh imw iru irv ifx],1,9) STERR([imh imw iru irv ifx],4,9)])


%% Plot parameter estimates (Figure A1)

COEFF(:,:) = STERR(:,1,:);
UP(:,:) = STERR(:,1,:) + 1.96*STERR(:,4,:);
DW(:,:) = STERR(:,1,:) - 1.96*STERR(:,4,:);

figure(1)
hold all
subplot(3,3,4)
plot((86:98),COEFF(izt,:),'Color','blue','LineStyle','-','LineWidth',2)
hold on
plot((86:98),UP(izt,:),'Color','black','LineStyle','--','LineWidth',1)
plot((86:98),DW(izt,:),'Color','black','LineStyle','--','LineWidth',1)
set(gca,'FontSize',6)
title('\zeta')
axis tight
subplot(3,3,7)
plot((86:98),COEFF(ifx,:),'Color','blue','LineStyle','-','LineWidth',2)
hold on
plot((86:98),UP(ifx,:),'Color','black','LineStyle','--','LineWidth',1)
plot((86:98),DW(ifx,:),'Color','black','LineStyle','--','LineWidth',1)
set(gca,'FontSize',6)
title('f')
axis tight
for k=2:3
    subplot(3,3,k)
    if k==2  
    plot((86:98),COEFF(k,:),'Color','blue','LineStyle','-','LineWidth',2)
    hold on
    plot((86:98),UP(k,:),'Color','black','LineStyle','--','LineWidth',1)
    plot((86:98),DW(k,:),'Color','black','LineStyle','--','LineWidth',1)
    set(gca,'FontSize',6)
    title('\sigma_u')
    axis tight
    elseif k==3  
    plot((86:98),COEFF(k,:),'Color','blue','LineStyle','-','LineWidth',2)
    hold on
    plot((86:98),UP(k,:),'Color','black','LineStyle','--','LineWidth',1)
    plot((86:98),DW(k,:),'Color','black','LineStyle','--','LineWidth',1) 
    set(gca,'FontSize',6)
    title('\sigma_v')
    axis tight    
    end
end
for k=5:6
    subplot(3,3,k)
    if k==5 
    plot((86:98),COEFF(k-1,:),'Color','blue','LineStyle','-','LineWidth',2)
    hold on
    plot((86:98),UP(k-1,:),'Color','black','LineStyle','--','LineWidth',1)
    plot((86:98),DW(k-1,:),'Color','black','LineStyle','--','LineWidth',1)
    set(gca,'FontSize',6)
    title('\rho_u')
    axis tight
    elseif k==6  
    plot((86:98),COEFF(k-1,:),'Color','blue','LineStyle','-','LineWidth',2)
    hold on
    plot((86:98),UP(k-1,:),'Color','black','LineStyle','--','LineWidth',1)
    plot((86:98),DW(k-1,:),'Color','black','LineStyle','--','LineWidth',1)
    set(gca,'FontSize',6)
    title('\rho_v')
    axis tight
    end
end
for k=8:9
    subplot(3,3,k)
    if k==8  
    plot((86:98),COEFF(k-2,:),'Color','blue','LineStyle','-','LineWidth',2)
    hold on
    plot((86:98),UP(k-2,:),'Color','black','LineStyle','--','LineWidth',1)
    plot((86:98),DW(k-2,:),'Color','black','LineStyle','--','LineWidth',1)
    set(gca,'FontSize',6)
    title('\mu_h')
    axis tight
    elseif k==9  
    plot((86:98),COEFF(k-2,:),'Color','blue','LineStyle','-','LineWidth',2)
    hold on
    plot((86:98),UP(k-2,:),'Color','black','LineStyle','--','LineWidth',1)
    plot((86:98),DW(k-2,:),'Color','black','LineStyle','--','LineWidth',1)   
    set(gca,'FontSize',6)
    title('\mu_w')
    axis tight
    end
end
subplot(3,3,1)
[haxes,hline1,hline2]=plotyy((86:98),COEFF(iah,:),(86:98),COEFF(iaw,:));
set(hline1,'LineWidth',2);
set(hline1,'Color','blue');
set(hline2,'LineWidth',2);
set(hline2,'Color',[0 .5 0]);
set(haxes(1),'FontSize',6,'YColor','k');
set(haxes(2),'FontSize',6,'YColor','k');
xlim(haxes(1),[86 98]);
xlim(haxes(2),[86 98]);
set(gca,'FontSize',6,'XTick',[86 88 90 92 94 96 98]);
hold on
[haxes,hline1,hline2]=plotyy((86:98),UP(iah,:),(86:98),UP(iaw,:));
set(hline1,'LineWidth',1,'LineStyle','--');
set(hline1,'Color','black');
set(hline2,'LineWidth',1,'LineStyle','--');
set(hline2,'Color','black');
set(haxes(1),'FontSize',6,'YColor','k');
set(haxes(2),'FontSize',6,'YColor','k');
xlim(haxes(1),[86 98]);
xlim(haxes(2),[86 98]);
set(gca,'FontSize',6,'XTick',[86 88 90 92 94 96 98]);
[haxes,hline1,hline2]=plotyy((86:98),DW(iah,:),(86:98),DW(iaw,:));
set(hline1,'LineWidth',1,'LineStyle','--');
set(hline1,'Color','black');
set(hline2,'LineWidth',1,'LineStyle','--');
set(hline2,'Color','black');
set(haxes(1),'FontSize',6,'YColor','k');
set(haxes(2),'FontSize',6,'YColor','k');
xlim(haxes(1),[86 98]);
xlim(haxes(2),[86 98]);
set(gca,'FontSize',6,'XTick',[86 88 90 92 94 96 98]);
title('\alpha_h and \alpha_w')

print -depsc estimates_over_time.eps;
print -dpdf estimates_over_time.pdf;

