%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% (NEGATIVE OF) LOG-LIKELIHOOD FUNCTION FOR MULTISECTOR STRUCTURAL MLE (see mainMLEmultidest.m)

function [f] = llf_md(Theta)

global izt isu isv iru irv imh1 imw1 imh2 imw2 imh3 imw3 ifx1 ifx2 ifx3 X eps


%% ------ DATA X ------ 
H = X(:,1);     % log employment
W = X(:,2);     % wage variable
I1 = X(:,3);     % export status 1
I2 = X(:,4);     % export status 2
I3 = X(:,5);     % export status 3
N = size(X,1);  % number of firms


%% ------ PARAMERERS ------
ztl  = Theta(izt);   % zeta
su2l = Theta(isu);   % sigma_u^2, transformed
sv2l = Theta(isv);   % sigma_v^2, transformed
rul  = Theta(iru);   % \tilde{rho}_u = rho_u/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
rvl  = Theta(irv);   % \tilde{rho}_v = rho_v/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
mhl1  = Theta(imh1);   % mu_h1
mwl1  = Theta(imw1);   % mu_w1
mhl2  = Theta(imh2);   % mu_h2
mwl2  = Theta(imw2);   % mu_w2
mhl3  = Theta(imh3);   % mu_h3
mwl3  = Theta(imw3);   % mu_w3
fxl1  = Theta(ifx1);   % f_x1 \tilde{f} = f/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
fxl2  = Theta(ifx2);   % f_x2, transformed
fxl3  = Theta(ifx3);   % f_x3, transformed

ahl = mean( H - mhl1*I1 - mhl2*I2 - mhl3*I3 );    % alpha_h
awl = mean( W - mwl1*I1 - mwl2*I2 - mwl3*I3 );    % alpha_w



%% ---------------------------- %%
% conditional mean E{z|h,w}
ml = rul * (H - ahl - mhl1*I1 - mhl2*I2 - mhl3*I3) / sqrt(max(su2l,eps)) ...
    + rvl * ( (W - awl - mwl1*I1 - mwl2*I2 - mwl3*I3) ...
    - ztl * (H - ahl - mhl1*I1 - mhl2*I2 - mhl3*I3) ) / sqrt(max(sv2l,eps));


llt = - N/2 * ( log(max(su2l,eps)) + log(max(sv2l,eps)) ) ...
    - (H - ahl - mhl1*I1 - mhl2*I2 - mhl3*I3)' * (H - ahl - mhl1*I1 - mhl2*I2 - mhl3*I3) / (2*max(su2l,eps)) ...
    - ((W - awl - mwl1*I1 - mwl2*I2 - mwl3*I3) - ztl*(H - ahl - mhl1*I1 - mhl2*I2 - mhl3*I3))' ...
    * ((W - awl - mwl1*I1 - mwl2*I2 - mwl3*I3) - ztl*(H - ahl - mhl1*I1 - mhl2*I2 - mhl3*I3)) / (2*max(sv2l,eps)) ...
    + (1-I1)' * log( max( normcdf( fxl1 - ml ,0,1) ,eps) ) ...
    + (I1-I2)' * log( max( normcdf( fxl1+fxl2 - ml ,0,1) - normcdf( fxl1 - ml ,0,1) ,eps) ) ...
    + (I2-I3)' * log( max(normcdf( fxl1+fxl2+fxl3 - ml ,0,1) - normcdf( fxl1+fxl2 - ml ,0,1) ,eps) ) ...
    + I3' * log( max( 1 - normcdf( fxl1+fxl2+fxl3 - ml ,0,1) ,eps) ) ;
    
f = - llt/N ;