%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% MOMENTS AND DISTRIBUTIONS (Tables 5-7 and Figure A2)

%%% First run mainMLE.m to generate ML Estimates written into THETA_MLE.csv


clear all
close all
clc
cd '/home/sjredding/himr-restud/matlab/brazil/'

global K izt isu isv iru irv imh imw ifx X



%% ------ PARAMETERS ------
K = 8;   % number of parameters to estimate

% indexes of the estimated parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f



%% --- LOAD DATA X ---
yr = 1994;
t = yr-1986+1;
data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1994-fun.csv');
%     Columns in firm-year data;

% Column 1 : cnpj_radic; 
% Column 2 : firm_subsibge; 
% Column 3 : year; 
% Column 4 : lwageyr;   
% Column 5 : wageyr; 
% Column 6 : reslwageyr; 
% Column 7 : obslwageyr; 
% Column 8 : felwageyr; 
% Column 9 : indexp; 
% Column 10 : employ; 
% Column 11 : indimp; 
% Column 12 : indexpusa; 
% Column 13 : meso; 
% Column 14 : state; 
% Column 15 : lwageyrmeso; 
% Column 16 : felwageyrmeso; 
% Column 17 : lemploymeso;
% Column 18 : indexpbin1; 
% Column 19 : indexpbin2; 
% Column 20 : indexpbin3; 
% Column 21 : forworker;
% Column 22 : nexpbin1; 
% Column 23 : nexpbin2; 
% Column 24 : nexpbin3;

N = size(data,1);       % number of observations (firms)
I = data(:,9);       % export status (dummy for exporter)
H = log(data(:,10));  % log employment
W = data(:,8);        % log wage (8 for FIRM FE PSI and 4 for MEAN LOG WAGE)
X = [H W I];            % data matrix



%% ------ GENERATE SIMULATED DATA ------
% --- Parameters of the model
THETA_MLE = csvread('THETA_MLE.csv'); 
TH = THETA_MLE(:,t);
ah = mean( H - TH(imh)*I );    % alpha_h
aw = mean( W - TH(imw)*I );    % alpha_w

% --- Generating draws of (u,v,z) --- 
% Covariance matrix for the shocks
Sigma = [TH(isu)^2 0 TH(iru)*TH(isu); 0 TH(isv)^2 TH(irv)*TH(isv); ...
    TH(iru)*TH(isu) TH(irv)*TH(isv) 1];

% Nx3 matrix of simulated shocks (u,v,z)
Rt = mvnrnd(zeros(1,3), Sigma , N*10 );
UU = Rt(:,1);
VV = Rt(:,2);
ZZ = Rt(:,3);

% --- Model-simulated data (h,w,iota)
IM = zeros(N*10 ,1);
IM( ZZ >= TH(ifx) ) = 1;
HM = ah + TH(imh)*IM + UU;
WM = aw + TH(imw)*IM + TH(izt)*UU + VV;
XM = [HM WM IM];
NM = size(XM,1);


%% CALCULATE MOMENTS (Tables 5-7): DATA vs MODEL
MOM = NaN*ones(33,2);

%% ------ TABLE 5: FIRM MOMEMNTS (DATA and MODEL) ------ 

% --- Unconditional (all firms)
MOM(1,:) = [mean(H) mean(HM)];          % mean employment
MOM(2,:) = [mean(W) mean(WM)];          % mean wages
MOM(3,:) = [std(H) std(HM)];            % st. dev. employment
MOM(4,:) = [std(W) std(WM)];            % st. dev. wages
MOM(5,:) = [corr(H,W) corr(HM,WM)];     % corr empl & wages
MOM(6,:) = [mean(I) mean(IM)];          % fraction exporters

% --- Non-exporters
MOM(8,:)  = [(1-I)'*H/sum(1-I) (1-IM)'*HM/sum(1-IM)];           % mean employment
MOM(9,:)  = [(1-I)'*W/sum(1-I) (1-IM)'*WM/sum(1-IM)];           % mean wages
MOM(10,:)  = [std(H(I==0)) std(HM(IM==0))];                     % st. dev. employment
MOM(11,:) = [std(W(I==0)) std(WM(IM==0))];                      % st. dev. wages
MOM(12,:) = [corr(H(I==0),W(I==0)) corr(HM(IM==0),WM(IM==0))];  % corr empl & wages

% --- Exporters
MOM(14,:)  = [I'*H/sum(I) IM'*HM/sum(IM)];                      % mean employment
MOM(15,:)  = [I'*W/sum(I) IM'*WM/sum(IM)];                      % mean wages
MOM(16,:)  = [std(H(I==1)) std(HM(IM==1))];                     % st. dev. employment
MOM(17,:) = [std(W(I==1)) std(WM(IM==1))];                      % st. dev. wages
MOM(18,:) = [corr(H(I==1),W(I==1)) corr(HM(IM==1),WM(IM==1))];  % corr empl & wages

disp('Table 5: Firm moments')
disp(MOM(1:18,1:2))



%% ------ TABLE 6: WORKER MOMENTS (DATA and MODEL) ------
% --- employment weights
wH = max(1,round(exp(H)));
wHM = max(1,round(exp(HM)));

% --- mean log worker wage
MOM(20,:) = [wH'*W/sum(wH) wHM'*WM/sum(wHM)];  % unconditional (all firms)
MOM(21,:) = [wH(I==0)'*W(I==0)/sum(wH(I==0)) wHM(IM==0)'*WM(IM==0)/sum(wHM(IM==0)) ]; % non-exporters
MOM(22,:) = [wH(I==1)'*W(I==1)/sum(wH(I==1)) wHM(IM==1)'*WM(IM==1)/sum(wHM(IM==1))];  % exporters

% --- st. dev. log worker wage
% unconditional (all firms)
MOM(24,:) = [ sqrt(wH'*W.^2/sum(wH) - (wH'*W/sum(wH))^2) ...
    sqrt(wHM'*WM.^2/sum(wHM) - (wHM'*WM/sum(wHM))^2)];
% non-exporters
MOM(25,:) = [ sqrt(wH(I==0)'*W(I==0).^2/sum(wH(I==0)) - (wH(I==0)'*W(I==0)/sum(wH(I==0)))^2) ...
    sqrt(wHM(IM==0)'*WM(IM==0).^2/sum(wHM(IM==0)) - (wHM(IM==0)'*WM(IM==0)/sum(wHM(IM==0)))^2)];
% exporters
MOM(26,:) = [ sqrt(wH(I==1)'*W(I==1).^2/sum(wH(I==1)) - (wH(I==1)'*W(I==1)/sum(wH(I==1)))^2) ...
    sqrt(wHM(IM==1)'*WM(IM==1).^2/sum(wHM(IM==1)) - (wHM(IM==1)'*WM(IM==1)/sum(wHM(IM==1)))^2)];

% employment share of exporters
MOM(28,:) = [I'*wH/sum(wH) IM'*wHM/sum(wHM)];

% ------ WAGE INEQUALITY ------
% --- Data
[Wsrt,ind_Wsrt] = sort(W);
cumH_Wsrt = cumsum(wH(ind_Wsrt))/sum(wH);
% --- Gini (discrete probability formula)
S = cumsum( wH(ind_Wsrt).*exp(Wsrt) / sum(wH) );
MOM(30,1) = 1 - wH(ind_Wsrt)'* (S + [0; S(1:end-1,1)]) / sum(wH) / S(end,1);
% --- 90/10, 90/50, 50/10 ratios
qeps = 0.0005;
ind10 = find((cumH_Wsrt>0.1-qeps/10)&(cumH_Wsrt<.1+qeps/10));
ind50 = find((cumH_Wsrt>0.5-qeps)&(cumH_Wsrt<.5+qeps));
ind90 = find((cumH_Wsrt>0.9-qeps)&(cumH_Wsrt<.9+qeps));
MOM(31,1) = exp( mean(W(ind_Wsrt(ind90))) - mean(W(ind_Wsrt(ind10))));
MOM(32,1) = exp( mean(W(ind_Wsrt(ind90))) - mean(W(ind_Wsrt(ind50))));
MOM(33,1) = exp( mean(W(ind_Wsrt(ind50))) - mean(W(ind_Wsrt(ind10))));

% --- Structural Model
[Wsrt,ind_Wsrt] = sort(WM);
cumH_Wsrt = cumsum(wHM(ind_Wsrt))/sum(wHM);
% --- Gini (discrete probability formula)
S = cumsum( wHM(ind_Wsrt).*exp(Wsrt) / sum(wHM) );
MOM(30,2) = 1 - wHM(ind_Wsrt)'* (S + [0; S(1:end-1,1)]) / sum(wHM) / S(end,1);
% --- 90/10, 90/50, 50/10 ratios
qeps = 0.0005;
ind10 = find((cumH_Wsrt>0.1-qeps/10)&(cumH_Wsrt<.1+qeps/10));
ind50 = find((cumH_Wsrt>0.5-qeps)&(cumH_Wsrt<.5+qeps));
ind90 = find((cumH_Wsrt>0.9-qeps)&(cumH_Wsrt<.9+qeps));
MOM(31,2) = exp( mean(WM(ind_Wsrt(ind90))) - mean(WM(ind_Wsrt(ind10))));
MOM(32,2) = exp( mean(WM(ind_Wsrt(ind90))) - mean(WM(ind_Wsrt(ind50))));
MOM(33,2) = exp( mean(WM(ind_Wsrt(ind50))) - mean(WM(ind_Wsrt(ind10))));

disp('Table 6: Worker wage dispersion')
disp(MOM([24:27 30 27 31 33 32],1:2))



%% ------ TABLE 7: SIZE AND EXPORTER WAGE PREMIA (DATA and MODEL) ------
% Regression of firm wages on firm employment and export status (coefficients and R^2)
btmp = ([ones(N,1) H I]'*[ones(N,1) H I])\([ones(N,1) H I]'*W);
MOM(35:36,1) = btmp(2:3,1);
MOM(37,1) = 1-(W - [ones(N,1) H I]*btmp)'*(W - [ones(N,1) H I]*btmp)/ ( (W-mean(W))'*(W-mean(W)) );

btmp = ([ones(NM,1) HM IM]'*[ones(NM,1) HM IM])\([ones(NM,1) HM IM]'*WM);
MOM(35:36,2) = btmp(2:3,1);
MOM(37,2) = 1-(WM - [ones(NM,1) HM IM]*btmp)'*(WM - [ones(NM,1) HM IM]*btmp)/ ( (WM-mean(WM))'*(WM-mean(WM)) );

disp('Table 7: Employment and Exporter Wage Premia')
disp(MOM(35:37,1:2))

% Save moments:
dlmwrite('MOMENTS94.csv',MOM,'precision','%14.6f','newline','pc');






%% ------ FIGURE A2: KERNEL DENSITIES  ------
% UPPER PANEL: FIRM EMPLOYMENT AND WAGES
figure(1)
subplot(3,2,1)
[ff,xx]=ksdensity(H);
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',1)
hold on
[ff,xx]=ksdensity(HM);
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',1)
llgg=legend('Data','Model','Location','northeast');
set(llgg,'FontSize',8);
title('Log Employment')
xlim([0 log(100000)])
set(gca,'YTick',[0 0.2 0.4])
set(gca,'XTick',[0 log(10) log(100) log(1000) log(100000)])
set(gca,'XTickLabel',{'1', '10', '100', '1000', '100000'})
subplot(3,2,2)
[ff,xx]=ksdensity(W);
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',1)
hold on
[ff,xx]=ksdensity(WM);
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',1)
title('Log Firm Wage Component')
xlim([log(1/8) log(4)])
set(gca,'YTick',[0 0.4 0.8])
set(gca,'XTick',[log(1/4) log(1/2) log(1) log(2) log(4)])
set(gca,'XTickLabel',{'1/4', '1/2', '1', '2', '4'})
subplot(3,2,3)
[ff,xx]=ksdensity(H(I==0));
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',1)
hold on
[ff,xx]=ksdensity(H(I==1));
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',2)
[ff,xx]=ksdensity(HM(IM==0));
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',1)
[ff,xx]=ksdensity(HM(IM==1));
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',2)
llgg=legend('Data Non','Data Exp','Model Non','Model Exp','Location','northeast');
set(llgg,'FontSize',8)
title('Exporters vs Non-exporters')
xlim([0 log(100000)])
set(gca,'YTick',[0 0.2 0.4 0.6])
set(gca,'XTick',[0 log(10) log(100) log(1000) log(100000)])
set(gca,'XTickLabel',{'1', '10', '100', '1000', '100000'})
subplot(3,2,4)
[ff,xx]=ksdensity(W(I==0));
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',1)
hold on
[ff,xx]=ksdensity(W(I==1));
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',2)
[ff,xx]=ksdensity(WM(IM==0));
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',1)
[ff,xx]=ksdensity(WM(IM==1));
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',2)
title('Exporters vs Non-exporters')
xlim([log(1/8) log(4)])
ylim([0 1.2])
set(gca,'YTick',[0 0.4 0.8 1.2])
set(gca,'XTick',[log(1/4) log(1/2) log(1) log(2) log(4)])
set(gca,'XTickLabel',{'1/4', '1/2', '1', '2', '4'})
subplot(3,2,5)
[ff,xx]=ksdensity(W,'weights',wH);
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',1)
hold on
[ff,xx]=ksdensity(WM,'weights',wHM);
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',1)
title('Log Worker Wages')
xlim([log(1/8) log(4)])
set(gca,'YTick',[0 0.4 0.8])
set(gca,'XTick',[log(1/4) log(1/2) log(1) log(2) log(4)])
set(gca,'XTickLabel',{'1/4', '1/2', '1', '2', '4'})
subplot(3,2,6)
[ff,xx]=ksdensity(W(I==0),'weights',wH(I==0));
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',1)
hold on
[ff,xx]=ksdensity(W(I==1),'weights',wH(I==1));
plot(xx,ff,'Color','blue','LineStyle','-.','LineWidth',2)
[ff,xx]=ksdensity(WM(IM==0),'weights',wHM(IM==0));
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',1)
[ff,xx]=ksdensity(WM(IM==1),'weights',wHM(IM==1));
plot(xx,ff,'Color','red','LineStyle','-','LineWidth',2)
title('Exporters vs Non-exporters')
xlim([log(1/8) log(4)])
ylim([0 1.2])
set(gca,'YTick',[0 0.4 0.8 1.2])
set(gca,'XTick',[log(1/4) log(1/2) log(1) log(2) log(4)])
set(gca,'XTickLabel',{'1/4', '1/2', '1', '2', '4'})

print -depsc moments_kernel.eps;
print -dpdf moments_kernel.pdf;










