%%% Calculating standard errors
%%% Input: data matrix X and (non-normalized) parameter vector Theta from unrestricted model
%%% Output: Vml variance matrixes (1 for Ess, 2 for Vss, and s for sandwich)
%%% Constrained model with K=9 parameters; mu_w=mu_h*zeta

clear all
close all

%%%% Users;
%%%% 1 : HIMR server;
%%%% 2 : Steve mac dropbox;
%%%% 3 : Oleg mac dropbox;

user=1;

if user==1;
cd /Users/reddings/Dropbox/HIMR/Restud3/replication/himr-restud/matlab/colombia/matlab/;
end;

clc

global K iah iaw izt isu isv iru irv imh imw ifx X eps

%%% ------ PARAMETERS ------ %%%
% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f
iah = 9;
iaw = 10;

eps=1e-10;

THETA_MLE = csvread('THETA_MLEsc.csv');

K0 = size(THETA_MLE,1);
T = size(THETA_MLE,2);

STERR=zeros(K0+2,4,T);

yr=1981-1;
syr=1981;
eyr=1991;
for t=1:T
yr = yr+1
t = yr-1981+1;
Theta0 = THETA_MLE(:,t);
Theta = Theta0([1:imw-1 imw+1:K0],1);

    if yr==1981;     data = csvread('../stata/coldata81.csv');
    elseif yr==1982; data = csvread('../stata/coldata82.csv');
    elseif yr==1983; data = csvread('../stata/coldata83.csv');
    elseif yr==1984; data = csvread('../stata/coldata84.csv');
    elseif yr==1985; data = csvread('../stata/coldata85.csv');
    elseif yr==1986; data = csvread('../stata/coldata86.csv');
    elseif yr==1987; data = csvread('../stata/coldata87.csv');
    elseif yr==1988; data = csvread('../stata/coldata88.csv');
    elseif yr==1989; data = csvread('../stata/coldata89.csv');
    elseif yr==1990; data = csvread('../stata/coldata90.csv');
    elseif yr==1991; data = csvread('../stata/coldata91.csv');
    end
    
    %COLUMN 1 : plant 
    %COLUMN 2 : year 
    %COLUMN 3 : sic3 
    %COLUMN 4 : employment 
    %COLUMN 5 : wage 
    %COLUMN 6 : exporter 

    N = size(data,1);       % number of observations
    H = log(data(:,4));     % log employment
    W = log(data(:,5));     % log wage 
    I = data(:,6);          % export status
    
    X = [H W I];            % data matrix
    


Theta = [Theta; mean(H-Theta0(imh)*I) ; mean(W-Theta0(imw)*I)];
Theta0 = [Theta0; mean(H-Theta0(imh)*I) ; mean(W-Theta0(imw)*I)];
K = size(Theta,1);


tic
vll=0;
Es=0;
Ess=0;
Vss=0;
for j=1:N
    vll = vll + llj_c(Theta,X(j,:));
    scorej = sj_c(Theta,X(j,:))';
    Es = Es + scorej;
    Ess = Ess + scorej*scorej';
    sprimej = reshape(ssj_c(Theta,X(j,:)),K,K);
    Vss = Vss + sprimej;
end
Es = Es/N;
Ess = Ess/N;
Vss = Vss/N;
toc

GM = eye(9);
GM = [GM(:,1:8) zeros(9,1) GM(:,9)];
GM(izt,9) = Theta0(imh,1);
GM(imh,9) = Theta0(izt,1);

Vml1 = GM'*inv(Ess)*GM/N;
Vml2 = GM'*inv(-Vss)*GM/N;
Vmls = GM'*inv(-Vss)*Ess*inv(-Vss)*GM/N;

disp('standard errors: score, hessian, sandwich')
STERR(:,:,t) = [Theta0 sqrt(diag(Vml1)) sqrt(diag(Vml2)) sqrt(diag(Vmls))];
STERR(:,:,t)


end

dlmwrite('STERRsc.csv',STERR,'precision','%14.6f','newline','pc');

disp('sandwich standard errors 1985');
display('stderr mu_h');
STERR(6,4,5)
display('stderr mu_w');
STERR(7,4,5)
display('stderr rho_u');
STERR(4,4,5)
display('stderr rho_v');
STERR(5,4,5)
display('stderr f');
STERR(8,4,5)

