%%% Log-likelihood of x_j for calculating standard errors
%%% Input: non-transformed parameter vector
%%% Constrained model with K=9 parameters; mu_w=mu_h*zeta


function [f] = llj_s(Theta,x);

global iah iaw izt isu isv iru irv imh imw ifx eps

%%%--------  Data X  ----------%%%
h = x(1);     % employment
w = x(2);     % wage
i = x(3);     % export status
%%%----------------------------%%%

%%%------  Parameters  --------%%%
ahl = Theta(iah-1,:);    % alpha_h
awl = Theta(iaw-1,:);    % alpha_w
ztl = Theta(izt,:);    % zeta
su2l = Theta(isu,:).^2;   % sigma_u^2, transformed
sv2l = Theta(isv,:).^2;   % sigma_v^2, transformed
rul = Theta(iru,:)./sqrt(1-Theta(iru,:).^2-Theta(irv,:).^2);    % \tilde{rho}_u = rho_u/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
rvl  = Theta(irv,:)./sqrt(1-Theta(iru,:).^2-Theta(irv,:).^2);    % \tilde{rho}_v = rho_v/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
mhl = Theta(imh,:);    % mu_h
% mwl = Theta(imw,:);    % mu_w
%%% note change below to ifx-1!
fxl = Theta(ifx-1,:)./sqrt(1-Theta(iru,:).^2-Theta(irv,:).^2);    % \tilde{f} = f/sqrt{1 - rho_u^2 - rho_v^2 }, transformed

mwl = mhl .* ztl; % constraint!

%%%----------------------------%%%
% conditional mean E{z|h,w}
ml = rul.*(h - ahl - mhl*i)./sqrt(max(su2l,eps)) + rvl.*( (w - awl - mwl*i) - ztl.*(h - ahl - mhl*i) )./sqrt(max(sv2l,eps));
% conditional st.dev., sqrt(V{z|h,w})
sl = 1; % if transformation used
% sl = sqrt(1-rul^2-rvl^2); % if transformation NOT used
%%%----------------------------%%%


llt = - ( log(max(su2l,eps)) + log(max(sv2l,eps)) ) /2 ...
    - (h - ahl - mhl*i) .* (h - ahl - mhl*i) ./ (2*max(su2l,eps)) ...
    - ((w - awl - mwl*i) - ztl.*(h - ahl - mhl*i)) .* ((w - awl - mwl*i) - ztl .*(h - ahl - mhl*i)) ./ (2*max(sv2l,eps)) ...
    + (1-i) * log( max( normcdf( (fxl - ml)./sl ,0,1) ,eps) ) ...
    + i * log( max( 1 - normcdf( (fxl - ml)./sl ,0,1) ,eps) );
    
f = llt;