%%% OLEG ITSKHOKI: HIMR, JANUARY 2013 (FIRST CODE: SEPTEMBER 2011)
%%% TRADE AND INEQUALITY: FROM THEORY TO ESTIMATION
%%% MAIN CODE FOR COUNTERFACTUAL EXERCISE

clear all
close all

%%%% Users;
%%%% 1 : HIMR server;
%%%% 2 : Steve mac dropbox;
%%%% 3 : Oleg mac dropbox;

user=1;

if user==1;
cd /Users/reddings/Dropbox/HIMR/Restud3/replication/himr-restud/matlab/colombia/matlab/;
end;

clc

global K izt isu isv iru irv imh imw ifx X


% Set default random number stream;
s = RandStream('mt19937ar','Seed',1);
RandStream.setGlobalStream(s);




%%% ------ PARAMETERS ------ %%%
K = 8;   % number of parameters to estimate
% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f







T = 1991-1981+1;    % number of years for estimation
yr = 1981-1;  % initial year for estimation
ESTIMATES=zeros(T,4);
PEAK=zeros(T,4);
% JUST FOR 1986;
%for t=6:6
%yr = yr + t;
% FOR ALL YEARS;
for t = 1:T
    yr = yr + 1
    
    % --- LOAD DATA X --- %
    %COLUMN 1 : plant 
    %COLUMN 2 : year 
    %COLUMN 3 : sic3 
    %COLUMN 4 : employment 
    %COLUMN 5 : wage 
    %COLUMN 6 : exporter 
    if yr==1981;     data = csvread('../stata/coldata81.csv');
    elseif yr==1982; data = csvread('../stata/coldata82.csv');
    elseif yr==1983; data = csvread('../stata/coldata83.csv');
    elseif yr==1984; data = csvread('../stata/coldata84.csv');
    elseif yr==1985; data = csvread('../stata/coldata85.csv');
    elseif yr==1986; data = csvread('../stata/coldata86.csv');
    elseif yr==1987; data = csvread('../stata/coldata87.csv');
    elseif yr==1988; data = csvread('../stata/coldata88.csv');
    elseif yr==1989; data = csvread('../stata/coldata89.csv');
    elseif yr==1990; data = csvread('../stata/coldata90.csv');
    elseif yr==1991; data = csvread('../stata/coldata91.csv');
    end





N = size(data,1);       % number of observations
H = log(data(:,4));     % log employment
W = log(data(:,5));     % log wage 
I = data(:,6);          % export status
    
X = [H W I];            % data matrix





%%% ------ SIMULATED DATA ------ %%%
% --- Parameters of the structural model
THETA_MLE = csvread('THETA_MLEsc.csv'); 
TH = THETA_MLE(:,t);
ah = mean( H - TH(imh)*I );    % alpha_h
aw = mean( W - TH(imw)*I );    % alpha_w



% --- Generating draws of (u,v,z) --- %
% Covariance matrix for the shocks
SG = [TH(isu)^2 0 TH(iru)*TH(isu); 0 TH(isv)^2 TH(irv)*TH(isv); ...
    TH(iru)*TH(isu) TH(irv)*TH(isv) 1];
% Nx3 matrix of observations of (u,v,z)
NS = N*10;
Rt = mvnrnd(zeros(1,3), eye(3) , NS );
RR = (SG^(1/2) * Rt')'; 

% --- Counterfactuals for alternative fixed exporting costs;
FF = [(-5:1:-3) (-2.5:.25:-1) (-.9:.1:.5) (.55:.05:2.5) (2.6:.1:3.5) (4:.5:5)]';
SDLW = zeros(size(FF,1),1);
SHX = zeros(size(FF,1),1);
EMPLX = zeros(size(FF,1),1);
for i = 1:size(FF,1);
    
    IM = zeros( NS ,1);
    IM( RR(:,3) >= FF(i,1) ) = 1;
    HM = ah + TH(imh)*IM + RR(:,1);
    WM = aw + TH(imw)*IM + TH(izt)*RR(:,1) + RR(:,2);
    XM = [HM WM IM];
    
    wHM = max(1,round(exp(HM)));
    SDLW(i,1) =  sqrt(wHM'*WM.^2/sum(wHM) - (wHM'*WM/sum(wHM))^2);
    EMPLX(i,1) = IM'*wHM/sum(wHM);
    SHX(i,1) = mean(IM);
    
    [FF(i,1) SDLW(i,1)]
    
end





figure(t)
plot(EMPLX,SDLW/min(SDLW),'Color','blue','LineStyle','-','LineWidth',1.5)
xlabel('Exporter Employment Share','FontSize',8)
ylabel('Standard deviation w (relative to autarky)','FontSize',8)
set(gca,'fontsize',8)
hold on




% --- Peak inequality;
Ipeak=(SDLW==max(SDLW));
display('>>>> Peak Inequality <<<<');
display('[FF(Ipeak==1) SDLW(Ipeak==1) EMPLX(Ipeak==1)]');
[FF(Ipeak==1) SDLW(Ipeak==1) EMPLX(Ipeak==1)]

PEAK(t,1)=t;
PEAK(t,2)=FF(Ipeak==1);
PEAK(t,3)=SDLW(Ipeak==1)/min(SDLW);
PEAK(t,4)=EMPLX(Ipeak==1);



% --- Inequality for estimated fixed exporting cost;
IM = zeros( NS ,1);
IM( RR(:,3) >= TH(ifx) ) = 1;
HM = ah + TH(imh)*IM + RR(:,1);
WM = aw + TH(imw)*IM + TH(izt)*RR(:,1) + RR(:,2);
XM = [HM WM IM];
    
wHM = max(1,round(exp(HM)));
BSDLW =  sqrt(wHM'*WM.^2/sum(wHM) - (wHM'*WM/sum(wHM))^2);
BEMPLX = IM'*wHM/sum(wHM);
BSHX = mean(IM);
    
display('>>>> Actual Inequality <<<<');
display('[TH(ifx) BSDLW BEMPLX]');
[TH(ifx) BSDLW BEMPLX]
    
ESTIMATES(t,1)=t;
ESTIMATES(t,2)=TH(ifx);
ESTIMATES(t,3)=BSDLW/min(SDLW);
ESTIMATES(t,4)=BEMPLX;



end;





