*! version 1.1  09dec2011  by Marc Muendler     muendler@ucsd.edu
*! version 1.2  12oct2012  by Marc Muendler     muendler@ucsd.edu
*! version 2.1  18apr2015  by Marc Muendler     muendler@ucsd.edu

version 9.2
set more off
set virtual on
clear
set trace off
set more off
set mem 20g
set matsize 1000

cd "$root"

capture log close
log using "$logs/sec-occ-samplecond.log", replace

capture program drop mklbl
program define mklbl
  local var = "`1'"
  local lblname = "`2'"
  * qui replace `var' = lower(`var')
  local num = _N
  * Shorten label names
  local lblname = substr("`lblname'",1,8)
  * English labels
  forvalues i = 1/`num' {
    local lblnum = `2'[`i']
    local lblstr = `1'[`i']
    label define `lblname' `lblnum' "`lblstr'", modify
    }
  label values `2' `lblname'
  label list `lblname'
  * label save `lblname' using "braxpmkt/conc/`lblname'", replace
end

foreach year of numlist 1986(1)1998 {
tempfile yr`year'

use pis cnpj_radic firm_subsibge wageyr cbogrp firm_cnae indprof indtech indwhit indsklb indunsklb indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem indhigh indscoll indgrad temp_empr using "$input/rais-secex-all-workers-`year'.dta", clear
do "$dofiles/routines/samplecond.do"

* Define variables
gen byte iscogrp = 5 if indprof==1
replace iscogrp = 4 if indtech==1
replace iscogrp = 3 if indwhit==1
replace iscogrp = 2 if indsklb==1
replace iscogrp = 1 if indunsklb==1
label var iscogrp "ISCO-88 Occupation group"
label define iscogrp 5 "Professional and Managerial occ." 4 "Technical and Supervisory occ occ." 3 "Other White Collar occ." 2 "Skill Intensive Blue Collar occ." 1 "Other Blue Collar occ.", modify
label values iscogrp iscogrp
keep pis firm_cnae firm_subsibge pis cbogrp iscogrp
gen int year = `year'
label var year "Calendar year"
order pis year

sort pis year
compress
save "`yr`year''"
}  // close `year' loop

use "`yr1986'", clear
foreach year of numlist 1987(1)1998 {
append using "`yr`year''"
}

tempfile secocc
sort pis year
save `secocc'

use pis firm_cnae firm_subsibge using `secocc', clear
drop if firm_cnae<=0 | firm_cnae==. 
qui do "$rawdata/cnae/cnae_95"
qui label save cnae_95 using "$tex/cnae_95", replace
qui count
local tot = `r(N)'
egen subsibge = mode(firm_subsibge), by(firm_cnae) maxmode
collapse (count) pis (mean) subsibge, by(firm_cnae) fast
replace pis = 100*(pis/`tot')
label values firm_cnae
rename firm_cnae _rowname
save "$tex/cnae_sc_tbl.dta", replace
matload cnae_sc_tbl, dropall p($tex) over
est2tex cnae_sc, replace dropall preserve ready vallabel(cnae_95) p($tex) fancy digits(1)

use pis cbogrp iscogrp using `secocc', clear
drop if cbogrp<=0 | cbogrp==.
qui label save cbogrp using "$tex/cbogrp", replace
qui count
local tot = `r(N)'
collapse (count) pis (mean) iscogrp, by(cbogrp) fast
replace pis = 100*(pis/`tot')
label values cbogrp
rename cbogrp _rowname
save "$tex/cbo_sc_tbl.dta", replace
matload cbo_sc_tbl, dropall p($tex) over
est2tex cbo_sc, replace dropall preserve ready vallabel(cbogrp) p($tex) fancy digits(1)

log close

