

#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s2mono;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global graphs="/home/sjredding/himr-restud/stata/graphs";

log using $logs/condwtvfe/tanova/tanalysis.log,replace;

*******************************************************************;
**** Merge within-between decomposition and employment weights ****;               
*******************************************************************;

clear;
u $data/condwtvfe/tanova/twithinbetween-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
tab _m;
drop _m;
sort firm_subsibge occup year;

gen tot_exp = firm_exp + obs_exp + cov_exp + res_exp;
gen tot_nonexp = firm_nonexp + obs_nonexp + cov_nonexp + res_nonexp;

********************;
**** AGGREGATES ****;
********************;

replace ttot = weight * ttot;
replace tobs = weight * tobs;
replace tcov = weight * tcov;
replace tbetween = weight * tbetween;
replace tres = weight * tres;
replace tbetweenfirm = weight * tbetweenfirm;
replace tbetweenmeso = weight * tbetweenmeso; 

replace tot_exp = weight * tot_exp;
replace obs_exp = weight * obs_exp;
replace cov_exp = weight * cov_exp;
replace firm_exp = weight * firm_exp;
replace res_exp = weight * res_exp;

replace tot_nonexp = weight * tot_nonexp;
replace obs_nonexp = weight * obs_nonexp;
replace cov_nonexp = weight * cov_nonexp;
replace firm_nonexp = weight * firm_nonexp;
replace res_nonexp = weight * res_nonexp;

collapse (sum) ttot tobs tcov tbetween tres tbetweenfirm tbetweenmeso 
tot_exp obs_exp cov_exp firm_exp res_exp 
tot_nonexp obs_nonexp cov_nonexp firm_nonexp res_nonexp
, by(year) fast;

gen test=ttot-(tobs+tcov+tbetween+tres);
replace test=int(test*10000);
su test, d;
drop test;

gen test=tbetween-(tbetweenfirm+tbetweenmeso);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist ttot tobs tcov tbetween tres tbetweenfirm tbetweenmeso {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_obs=tobs/ttot;
gen sh_cov=tcov/ttot;
gen sh_between=tbetween/ttot;
gen sh_res=tres/ttot;

foreach var of varlist sh_obs sh_cov sh_between sh_res {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist ttot tobs tcov tbetween tres {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_obs86=(sh_obs86*d_tobs86)/d_ttot86;
gen cnt_cov86=(sh_cov86*d_tcov86)/d_ttot86;
gen cnt_between86=(sh_between86*d_tbetween86)/d_ttot86;
gen cnt_res86=(sh_res86*d_tres86)/d_ttot86;

gen data=1;

**** Decomposition of level of within-sector occupation wage inequality 1994;
**** into worker observables, covariance and within and between firm components;

**** Table 2, Column (3), Rows (1)-(4);
**** sh_obs is share observables;
**** sh_cov is share covariance;
**** sh_between is share between-firm;
**** sh_res is share within-firm;

format sh_obs sh_cov sh_between sh_res %10.3f;
table data if year==1994, c(mean sh_obs mean sh_between mean sh_cov mean sh_res);

**** Decomposition of changes in within-sector occupation wage inequality 1986-95;
**** into worker observables, covariance and within and between firm components;

**** Table 2, Column (4), Rows (1), Between firm;

format cnt_between86 %10.3f;
table data if year==1995, c(mean cnt_between86);

**** Table 2, Column (4), Row (2), Within firm;

format cnt_res86 %10.3f;
table data if year==1995, c(mean cnt_res86);

**** Table 2, Column (4), Row (3), Observables;

format cnt_obs86 %10.3f;
table data if year==1995, c(mean cnt_obs86);

**** Table 2, Column (4), Row (4), Covariance;

format cnt_cov86 %10.3f;
table data if year==1995, c(mean cnt_cov86);

*************************************;
* Decomposition for exporting firms *;
*************************************;

gen sh_obs_exp=obs_exp/tot_exp;
gen sh_cov_exp=cov_exp/tot_exp;
gen sh_firm_exp=firm_exp/tot_exp;
gen sh_res_exp=res_exp/tot_exp;

*****************************************;
* Decomposition for non-exporting firms *;
*****************************************;

gen sh_obs_nonexp=obs_nonexp/tot_nonexp;
gen sh_cov_nonexp=cov_nonexp/tot_nonexp;
gen sh_firm_nonexp=firm_nonexp/tot_nonexp;
gen sh_res_nonexp=res_nonexp/tot_nonexp;

**** Table H8 Online Supplement : Exporters panel; 
**** Column (2);

**** Decomposition of the level within-sector occupation wage inequality in 1994;
**** into the following components; 
**** sh_firm_exp : between-firm component;
**** sh_res_exp : within-firm component;
**** sh_obs_exp : observables component;
**** sh_cov_exp : covariance component;

format sh_firm_exp sh_res_exp sh_obs_exp sh_cov_exp %10.2f;
table data if year==1994, c(mean sh_firm_exp mean sh_res_exp mean sh_obs_exp mean sh_cov_exp);

**** Table H8 Online Supplement : Non-exporters panel; 
**** Column (2);

**** Decomposition of the level within-sector occupation wage inequality in 1994;
**** into the following components; 
**** sh_firm_exp : between-firm component;
**** sh_res_exp : within-firm component;
**** sh_obs_exp : observables component;
**** sh_cov_exp : covariance component;

format sh_firm_nonexp sh_res_nonexp sh_obs_nonexp sh_cov_nonexp %10.2f;
table data if year==1994, c(mean sh_firm_nonexp mean sh_res_nonexp mean sh_obs_nonexp mean sh_cov_nonexp);

*****************************************************************;
* Decompose between firm into between region and within regions *;
*****************************************************************;

gen sh_betweenfirm=tbetweenfirm/tbetween;
gen sh_betweenmeso=tbetweenmeso/tbetween;

foreach var of varlist sh_betweenfirm sh_betweenmeso {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist tbetweenfirm tbetweenmeso {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_betweenfirm86=(sh_betweenfirm86*d_tbetweenfirm86)/d_tbetween86;
gen cnt_betweenmeso86=(sh_betweenmeso86*d_tbetweenmeso86)/d_tbetween86;

**** Footnote 15;
**** Decomposition of variance of level of firm fixed effects in 1994; 
**** into within region and between region;
**** sh_betweenmeso : between meso region;
**** sh_betweenfirm : within meso region (between firm);

format sh_betweenfirm sh_betweenmeso %10.3f;
table data if year==1994, c(mean sh_betweenfirm mean sh_betweenmeso);

**** Footnote 15;
**** Decomposition of variance of growth of firm fixed effects from 1986-95; 
**** into within region and between region;

**** cnt_betweenmeso86 : between meso region;

format cnt_betweenmeso86 %10.3f;
table data if year==1995, c(mean cnt_betweenmeso86);

**** cnt_betweenfirm86 : within meso region (between firm);

format cnt_betweenfirm86 %10.3f;
table data if year==1995, c(mean cnt_betweenfirm86);

*********************************************************;
* Graphs of the decomposition for the online supplement *;
*********************************************************;

**** Figure H8, Online Supplement;
**** Decompose within-sector occupation inequality into;
**** between-firm, within-firm, observables and covariance;

twoway (scatter ittot year , msymbol(i) c(l) lcolor(black) lpattern(solid) lwidth(thick))
(scatter itobs year , msymbol(oh) mcolor(orange) c(l) lcolor(orange) lpattern(dash) lwidth(medium))
(scatter itcov year , msymbol(oh) mcolor(cyan) c(l) lcolor(cyan) lpattern(solid) lwidth(medium))
(scatter itbetween year , msymbol(i) c(l) lcolor(purple) lpattern(dash) lwidth(thick))
(scatter itres year , msymbol(D) mcolor(gray) c(l) lcolor(gray) lpattern(solid) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Worker Obs") lab(3 "Covariance") lab(4 "Between-Firm") lab(5 "Within-Firm") cols(3) rows(2))
xlabel(1986 1990 1994 1998)
xtitle(Year)
ytitle(Index (1986=0))
saving($graphs/condwtvfe/tanova/agg-index,replace)
;

graph export $graphs/condwtvfe/tanova/agg-index.eps, as(eps) replace;

log close;


