

#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s2mono;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global graphs="/home/sjredding/himr-restud/stata/graphs";

capture log close;
log using $logs/condwtvfe/tanova/tanalysis_educ.log,replace;

*********************************************************************************************;
**** Robustness test for decomposition of wage inequality within sector-occupation-years ****;
**** using more disaggregated education measures                                         ****;
*********************************************************************************************;

*******************************************************************;
**** Merge within-between decomposition and employment weights ****;               
*******************************************************************;

clear;
u $data/condwtvfe/tanova/twithinbetween-educ-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
drop _m;
keep if firm_subsibge>=2 &firm_subsibge<=13;
sort firm_subsibge occup year;

********************;
**** AGGREGATES ****;
********************;

replace ttot = weight * ttot;
replace tobs = weight * tobs;
replace tcov = weight * tcov;
replace tbetween = weight * tbetween;
replace tres = weight * tres;

collapse (sum) ttot tobs tcov tbetween tres , by(year);

gen test=ttot-(tobs+tcov+tbetween+tres);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist ttot tobs tcov tbetween tres {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_obs=tobs/ttot;
gen sh_cov=tcov/ttot;
gen sh_between=tbetween/ttot;
gen sh_res=tres/ttot;

foreach var of varlist sh_obs sh_cov sh_between sh_res {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist ttot tobs tcov tbetween tres {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_obs86=(sh_obs86*d_tobs86)/d_ttot86;
gen cnt_cov86=(sh_cov86*d_tcov86)/d_ttot86;
gen cnt_between86=(sh_between86*d_tbetween86)/d_ttot86;
gen cnt_res86=(sh_res86*d_tres86)/d_ttot86;

gen data=1;

**** Results discussed in text of Section H7 of the online supplement;
**** Decomposition of level of within-sector occupation wage inequality 1994;
**** into worker observables, covariance and within and between firm components;
**** using more disaggregated education categories;

**** sh_between is share between-firm;
**** sh_res is share within-firm;
**** sh_obs is share observables;
**** sh_cov is share covariance;

* Level contributions in 1994;

format sh_between sh_res sh_obs sh_cov %10.3f;
table data if year==1994, c(mean sh_between mean sh_res mean sh_obs mean sh_cov);

**** Results discussed in text of Section H7 of the online supplement;
**** Decomposition of changes in within-sector occupation wage inequality 1986-95;
**** into worker observables, covariance and within and between firm components;
**** using more disaggregated education categories;

* Between-firm Growth contributions 1986-1995;

format cnt_between86 %10.3f;
table data if year==1995, c(mean cnt_between86);

* Within-firm Growth contributions 1986-1995;

format cnt_res86 %10.3f;
table data if year==1995, c(mean cnt_res86);

* Observables Growth contributions 1986-1995;

format cnt_obs86 %10.3f;
table data if year==1995, c(mean cnt_obs86);

* Covariance Observables Firm Component Growth contributions 1986-1995;

format cnt_cov86 %10.3f;
table data if year==1995, c(mean cnt_cov86);

log close;


