

#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s2mono;
capture log close;

*********************************************************************************;
**** Robustness test for wage inequality within sector-occupation-year cells ****;
**** excluding time-varying firm wage component                              ****;
*********************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/condwtvfe/tanova/tanalysis_robust.log,replace;

*******************************************************************;
**** Merge within-between decomposition and employment weights ****;               
*******************************************************************;

clear;
u $data/condwtvfe/tanova/twithinbetween-robust-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
tab _m;
drop _m;
sort firm_subsibge occup year;

********************;
**** AGGREGATES ****;
********************;

replace ttot = weight * ttot;
replace tobs = weight * tobs;
replace tres = weight * tres;

collapse (sum) ttot tobs tres , by(year);

gen test=ttot-(tobs+tres);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist ttot tobs tres {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_obs=tobs/ttot;
gen sh_res=tres/ttot;

foreach var of varlist sh_obs sh_res {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist ttot tobs tres {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_obs86=(sh_obs86*d_tobs86)/d_ttot86;
gen cnt_res86=(sh_res86*d_tres86)/d_ttot86;

gen data=1;

* Level contributions in 1994;

format sh_obs sh_res %10.3f;
table data if year==1994, c(mean sh_obs mean sh_res);

log close;


