clear
clear matrix
program drop _all
set more off
set virtual on
set mem 100m
set trace off
set matsize 150

// check temporary directory
! export STATATMP=/u/data/tmp
tempfile findout
* disp "`findout'"
if substr("`findout'",1,12)~="/u/data/tmp/"  STOP  // default /tmp/ too small to use

global dofiles "/u/data/himr/code/stata/dofiles"
global logs    "/u/data/himr/code/stata/logs/pnad"
global grph    "/u/data/himr/code/stata/graphs/pnad"
global grphcc  "/u/data/himr/code/stata/graphs/pnad-comcart"
global input   "/u/data/himr/input"
global data    "/u/data/himr/restud"

cd "$data"
program drop _all
adopath + "/u/data/himr/code/ado/"
qui do "/u/data/himr/code/ado/%Read-tabl2tex.do"

capture mkdir "$logs"
capture mkdir "$data/pnad"
capture mkdir "$data/pnad/prepdata"
capture mkdir "$data/pnad/prepdata-comcart"
capture mkdir "$data/pnad/sector-occupation"
capture mkdir "$data/pnad/sector-occupation-comcart"
capture mkdir "$grph"
capture mkdir "$grph/sector-occupation"
capture mkdir "$grphcc"
capture mkdir "$grphcc/sector-occupation"

*================================================================
* Table H12: Columns (1)-(2) Table A1
*            Columns (3)-(4) dofiles/pnad/pnad-descrip-comcart.do
*            Columns (5)-(6) dofiles/pnad/pnad-descrip.do
*================================================================

*================================================================
* Table H13: Columns (1)-(2) Table A2
*            Columns (3)-(4) dofiles/pnad/pnad-descrip-comcart.do
*            Columns (5)-(6) dofiles/pnad/pnad-descrip.do
*================================================================

* do "$dofiles/pnad/pnad-descrip.do"
    /* GENERATE DESCRIPTIVES IN TABLE 1 AND TABLE 2, MAIN INEQUALITY PLOT */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond.do" */
    /* OUTPUT: "$data/pnad/prepdata/o-descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata/o-descrip-all.dta"
               "$data/pnad/prepdata/i-descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata/i-descrip-all.dta"
               "$data/pnad/prepdata/e-descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata/e-descrip-all.dta"
               "$data/pnad/prepdata/descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata/descrip-all.dta"
       graphs: "$grph/occ_empsh.gph"
               "$grph/ind_empsh1.gph"
               "$grph/ind_empsh2.gph"
               "$grph/ind_empsh3.gph"
               "$grph/ind_empsh_all.gph"
               "$grph/mn_var_lwageyr.gph"
               "$grph/mn_var_lwageyr_bw.gph" */
    /*    Log: "$logs/descrip.log" */

* do "$dofiles/pnad/pnad-descrip-comcart.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). GENERATE DESCRIPTIVES IN TABLE 1 AND TABLE 2, MAIN INEQUALITY PLOT */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond-comcart.do" */
    /* OUTPUT: "$data/pnad/prepdata-comcart/o-descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata-comcart/o-descrip-all.dta"
               "$data/pnad/prepdata-comcart/i-descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata-comcart/i-descrip-all.dta"
               "$data/pnad/prepdata-comcart/e-descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata-comcart/e-descrip-all.dta"
               "$data/pnad/prepdata-comcart/descrip`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
               "$data/pnad/prepdata-comcart/descrip-all.dta"
       graphs: "$grphcc/occ_empsh.gph"
               "$grphcc/ind_empsh1.gph"
               "$grphcc/ind_empsh2.gph"
               "$grphcc/ind_empsh3.gph"
               "$grphcc/ind_empsh_all.gph"
               "$grphcc/mn_var_lwageyr.gph"
               "$grphcc/mn_var_lwageyr_bw.gph" */
    /*    Log: "$logs/descrip-comcart.log" */

*===========================================================
* Table H14: Column (1): Table 1, column (1), rows (1)-(6)
*            Column (2), Rows (1)-(5) soanalysis-comcart.do
*            Column (2), Row (6) soanalysis-comcart_ramo.do
*            Column (3), Rows (1)-(5) soanalysis.do
*            Column (3), Row (6) soanalysis_ramo.do
*===========================================================

* do "$dofiles/pnad/pnad-soanova.do"
    /* PREPARE DATA FOR CONDITIONAL RESULTS IN TABLE H14 */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond.do" */
    /* OUTPUT: "$data/pnad/sector-occupation/withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /*    Log: "$logs/soanova.log" */

* do "$dofiles/pnad/pnad-soanova-comcart.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). PREPARE DATA FOR CONDITIONAL RESULTS IN TABLE H14 */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond-comcart.do" */
    /* OUTPUT: "$data/pnad/sector-occupation-comcart/withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /*    Log: "$logs/soanova-comcart.log" */

* do "$dofiles/pnad/pnad-soanalysis.do"
    /* GENERATE CONDITIONAL RESULTS IN TABLE H14 */
    /* INPUT:  "$data/pnad/sector-occupation/withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /* OUTPUT: "$data/pnad/sector-occupation/withinbetween-all.dta"
               "$data/pnad/sector-occupation/univ-sectoroccupation-all.csv"
       graphs: "$grph/sector-occupation/uncond_level_all_bw.gph"
               "$grph/sector-occupation/sector.gph"
               "$grph/sector-occupation/occupation.gph"
               "$grph/sector-occupation/sectoroccupation.gph"
               "$grph/sector-occupation/so_index.gph"
               "$grph/sector-occupation/uncond_level_all.gph"
               "$grph/sector-occupation/u-i-sector.gph"
               "$grph/sector-occupation/u-i-occupation.gph"
               "$grph/sector-occupation/u-i-sectoroccupation.gph"
               "$grph/sector-occupation/uncond_level_all_det.gph"
               "$grph/sector-occupation/u-i-occupation-det.gph"
               "$grph/sector-occupation/u-i-sectoroccupation-det.gph"
               "$grph/sector-occupation/u-i-lwageyr-9010.gph" */
    /*    Log: "$logs/soanalysis.log" */

* do "$dofiles/pnad/pnad-soanalysis-comcart.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). GENERATE CONDITIONAL RESULTS IN TABLE H14 */
    /* INPUT:  "$data/pnad/sector-occupation-comcart/withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /* OUTPUT: "$data/pnad/sector-occupation-comcart/withinbetween-all.dta"
               "$data/pnad/sector-occupation-comcart/univ-sectoroccupation-all.csv"
       graphs: "$grph/sector-occupation/uncond_level_all_bw.gph"
               "$grph/sector-occupation/sector.gph"
               "$grph/sector-occupation/occupation.gph"
               "$grph/sector-occupation/sectoroccupation.gph"
               "$grph/sector-occupation/so_index.gph"
               "$grph/sector-occupation/uncond_level_all.gph"
               "$grph/sector-occupation/u-i-sector.gph"
               "$grph/sector-occupation/u-i-occupation.gph"
               "$grph/sector-occupation/u-i-sectoroccupation.gph"
               "$grph/sector-occupation/uncond_level_all_det.gph"
               "$grph/sector-occupation/u-i-occupation-det.gph"
               "$grph/sector-occupation/u-i-sectoroccupation-det.gph"
               "$grph/sector-occupation/u-i-lwageyr-9010.gph" */
    /*    Log: "$logs/soanalysis-comcart.log" */

* do "$dofiles/pnad/pnad-soanova_ramo.do"
    /* PREPARE DATA FOR CONDITIONAL RESULTS WITH DETAILED SECTOR-OCCUPATIONS IN TABLE H14 */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond.do" */
    /* OUTPUT: "$data/pnad/sector-occupation/withinbetween-`year'-alt.dta" (`year' in 1995(1)1998) */
    /*    Log: "$logs/soanova_ramo.log" */

* do "$dofiles/pnad/pnad-soanova-comcart_ramo.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). PREPARE DATA FOR CONDITIONAL RESULTS WITH DETAILED SECTOR-OCCUPATIONS IN TABLE H14 */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond-comcart.do" */
    /* OUTPUT: "$data/pnad/sector-occupation-comcart/withinbetween-`year'-alt.dta" (`year' in 1995(1)1998) */
    /*    Log: "$logs/soanova-comcart_ramo.log" */

* do "$dofiles/pnad/pnad-soanalysis_ramo.do"
    /* GENERATE CONDITIONAL RESULTS WITH DETAILED SECTOR-OCCUPATIONS IN TABLE H14 */
    /* INPUT:  "$data/pnad/sector-occupation/withinbetween-`year'-alt.dta" (`year' in 1995(1)1998)
               ["$data/pnad/sector-occupation/withinbetween-all.dta"] */
    /* OUTPUT: "$data/pnad/sector-occupation/withinbetween-all-alt.dta"
       graphs: "$grph/sector-occupation/uncond_level_all_alt.gph"
               "$grph/sector-occupation/u-i-sector-alt.gph"
               "$grph/sector-occupation/u-i-occupation-alt.gph"
               "$grph/sector-occupation/u-i-sectoroccupation-alt.gph"
               "$grph/sector-occupation/u-i-so-all-alt.gph" */
    /*    Log: . */

* do "$dofiles/pnad/pnad-soanalysis-comcart_ramo.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). GENERATE CONDITIONAL RESULTS WITH DETAILED SECTOR-OCCUPATIONS IN TABLE H14 */
    /* INPUT:  "$data/pnad/sector-occupation-comcart/withinbetween-`year'-alt.dta" (`year' in 1995(1)1998)
               ["$data/pnad/sector-occupation-comcart/withinbetween-all.dta"] */
    /* OUTPUT: "$data/pnad/sector-occupation-comcart/withinbetween-all-alt.dta"
       graphs: "$grphcc/sector-occupation/uncond_level_all_alt.gph"
               "$grphcc/sector-occupation/u-i-sector-alt.gph"
               "$grphcc/sector-occupation/u-i-occupation-alt.gph"
               "$grphcc/sector-occupation/u-i-sectoroccupation-alt.gph"
               "$grphcc/sector-occupation/u-i-so-all-alt.gph" */
    /*    Log: . */

*===========================================================
* Table H15: Column (1): Table 1, column (1), rows (7)-(8)
*            Column (2), Rows (7)-(8) csoanalysis-comcart.do
*            Column (3), Rows (7)-(8) csoanalysis.do
*===========================================================

* do "$dofiles/pnad/pnad-csoanova.do"
    /* PREPARE DATA FOR CONDITIONAL RESULTS IN TABLE H15 */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond.do" */
    /* OUTPUT: "$data/pnad/sector-occupation/c-withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /*    Log: "$logs/csoanova.log"
               "$logs/cso-statsig.log" */

* do "$dofiles/pnad/pnad-csoanova-comcart.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). PREPARE DATA FOR CONDITIONAL RESULTS IN TABLE H15 */
    /* INPUT:  "$input/pnad`year'pes_comp81_likerais.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998)
           Do: "$dofiles/routines/pnad-samplecond-comcart.do" */
    /* OUTPUT: "$data/pnad/sector-occupation-comcart/c-withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /*    Log: "$logs/csoanova-comcart.log"
               "$logs/cso-statsig-comcart.log" */

* do "$dofiles/pnad/pnad-csoanalysis.do"
    /* GENERATE CONDITIONAL RESULTS IN TABLE H15 */
    /* INPUT:  "$data/pnad/sector-occupation/c-withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /* OUTPUT: "$data/pnad/sector-occupation/c-withinbetween-all.dta"
               "$data/pnad/sector-occupation/univ-c-sectoroccupation-all.csv"
               "$data/pnad/sector-occupation/cso-mincer-coeff-results-year.csv"
               "$data/pnad/sector-occupation/cso-mincer-se-results-year.csv"
       graphs: "$grph/sector-occupation/educreturns.gph"
               "$grph/sector-occupation/agereturns.gph"
               "$grph/sector-occupation/c-i-sector.gph"
               "$grph/sector-occupation/c-i-occupation.gph"
               "$grph/sector-occupation/c-i-sectoroccupation.gph"
               "$grph/sector-occupation/c-i-rawobs.gph"
               "$grph/sector-occupation/c-i-sector-alt.gph"
               "$grph/sector-occupation/c-i-occupation-alt.gph"
               "$grph/sector-occupation/c-i-sectoroccupation-alt.gph"
               "$grph/sector-occupation/total-obs-within-all.gph"
               "$grph/sector-occupation/c-i-rawobs-bw.gph"
               "$grph/sector-occupation/c-i-sector-alt-bw.gph"
               "$grph/sector-occupation/c-i-occupation-alt-bw.gph"
               "$grph/sector-occupation/c-i-sectoroccupation-alt-bw.gph"
               "$grph/sector-occupation/within-group-so-all-bw.gph"
               "$grph/sector-occupation/c-sector.gph"
               "$grph/sector-occupation/c-occupation.gph"
               "$grph/sector-occupation/c-sectoroccupation.gph" */
    /*    Log: . */

* do "$dofiles/pnad/pnad-csoanalysis-comcart.do"
    /* FORMAL WORKERS ONLY (COM CARTEIRA). GENERATE CONDITIONAL RESULTS IN TABLE H15 */
    /* INPUT:  "$data/pnad/sector-occupation-comcart/c-withinbetween-`year'.dta" (`year' in 1986(1)1990 1992(1)1993 1995(1)1998) */
    /* OUTPUT: "$data/pnad/sector-occupation-comcart/c-withinbetween-all.dta"
               "$data/pnad/sector-occupation-comcart/univ-c-sectoroccupation-all.csv"
               "$data/pnad/sector-occupation-comcart/cso-mincer-coeff-results-year.csv"
               "$data/pnad/sector-occupation-comcart/cso-mincer-se-results-year.csv"
       graphs: "$grphcc/sector-occupation/educreturns.gph"
               "$grphcc/sector-occupation/agereturns.gph"
               "$grphcc/sector-occupation/c-i-sector.gph"
               "$grphcc/sector-occupation/c-i-occupation.gph"
               "$grphcc/sector-occupation/c-i-sectoroccupation.gph"
               "$grphcc/sector-occupation/c-i-rawobs.gph"
               "$grphcc/sector-occupation/c-i-sector-alt.gph"
               "$grphcc/sector-occupation/c-i-occupation-alt.gph"
               "$grphcc/sector-occupation/c-i-sectoroccupation-alt.gph"
               "$grphcc/sector-occupation/total-obs-within-all.gph"
               "$grphcc/sector-occupation/c-i-rawobs-bw.gph"
               "$grphcc/sector-occupation/c-i-sector-alt-bw.gph"
               "$grphcc/sector-occupation/c-i-occupation-alt-bw.gph"
               "$grphcc/sector-occupation/c-i-sectoroccupation-alt-bw.gph"
               "$grphcc/sector-occupation/within-group-so-all-bw.gph"
               "$grphcc/sector-occupation/c-sector.gph"
               "$grphcc/sector-occupation/c-occupation.gph"
               "$grphcc/sector-occupation/c-sectoroccupation.gph" */
    /*    Log: . */
