#delimit;

clear;
clear matrix;
set more off;
capture log close; 

log using $logs/csoanova-comcart.log, replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach year of numlist 1986(1)1990 1992(1)1993 1995(1)1998 {;

use $input/pnad`year'pes_comp81_likerais.dta, clear;

* Define sample;

do $dofiles/routines/pnad-samplecond-comcart.do;

***************;
**** Setup ****;
***************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

* Categorical variables;

egen secoccup = group(firm_subsibge occup);
egen soo = group(firm_subsibge cbogrp);

* Descriptives;

codebook firm_subsibge;
codebook occup;
codebook secoccup;
codebook cbogrp;
codebook soo;

* Single Mincer regression;
reg lwageyr `demog' `educ', robust;  // note: tenure2-tenure5 cannot be included;
predict clwageyr if e(sample), res;
predict flwageyr if e(sample), xb;
gen b_indhigh=_b[indhigh]; 
gen b_indscoll=_b[indscoll]; 
gen b_indgrad=_b[indgrad];
gen b_indchild=_b[indchild];
gen b_indyouth=_b[indyouth];
gen b_indadol=_b[indadol];
gen b_indnasc=_b[indnasc];
gen b_indearly=_b[indearly];
gen b_indpeak=_b[indpeak];
gen b_indlate=_b[indlate];
gen b_indretir=_b[indretir];
gen b_indfem=_b[indfem];

gen se_indhigh=_se[indhigh]; 
gen se_indscoll=_se[indscoll]; 
gen se_indgrad=_se[indgrad];
gen se_indchild=_se[indchild];
gen se_indyouth=_se[indyouth];
gen se_indadol=_se[indadol];
gen se_indnasc=_se[indnasc];
gen se_indearly=_se[indearly];
gen se_indpeak=_se[indpeak];
gen se_indlate=_se[indlate];
gen se_indretir=_se[indretir];
gen se_indfem=_se[indfem];

gen regR2=e(r2);
gen regobs=e(N);

* Raw wage dispersion;
egen temp=sd(lwageyr);
gen wgedisp = temp*temp;
drop temp;

* Observables component;
egen temp=sd(flwageyr);
gen obsdisp = temp*temp;
drop temp;

* within/between decomposition for sectors;
areg clwageyr, abs(firm_subsibge);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sbetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen swithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen scond = swithin + sbetween;

* within/between decomposition for occupations;
areg clwageyr, abs(occup);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen obetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen owithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen ocond = owithin + obetween;

* within/between decompositions for sector-occupations;
areg clwageyr, abs(secoccup);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen sowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen socond = sowithin + sobetween;

* within/between decomposition for detailed occupations;
areg clwageyr, abs(cbogrp);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen oobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen oowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen oocond = oowithin + oobetween;

* within/between decompositions for detailed sector - detailed occupations;
areg clwageyr, abs(soo);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen soobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen soowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen soocond = soowithin + soobetween;

**************;
**** Test ****;
**************;

* Sectors;
gen test=wgedisp-(obsdisp+swithin+sbetween);
replace test=int(10000*test);
su test, d;
drop test;

* Occupations;
gen test=wgedisp-(obsdisp+owithin+obetween);
replace test=int(10000*test);
su test, d;
drop test;

* Sector-occupations;
gen test=wgedisp-(obsdisp+sowithin+sobetween);
replace test=int(10000*test);
su test, d;
drop test;

*************;
* Save Data *;
*************;

gen year=`year';

so firm_ramo occup hhid year;
sa $data/pnad/sector-occupation-comcart/c-withinbetween-`year'.dta,replace;

};

log close;

*********************************;
* Test Statistical Significance *;
*********************************;

log using $logs/cso-statsig-comcart.log, replace;
u $data/pnad/sector-occupation-comcart/c-withinbetween-1990.dta, clear;
append using $data/pnad/sector-occupation-comcart/c-withinbetween-1995.dta;
so firm_ramo occup hhid year;

robvar clwageyr, by(year);

u $data/pnad/sector-occupation-comcart/c-withinbetween-1995.dta, clear;
append using $data/pnad/sector-occupation-comcart/c-withinbetween-1998.dta;
so firm_ramo occup hhid year;

robvar clwageyr, by(year);
log close;

***********************;
* Save Collapsed Data *;
***********************;

foreach year of numlist 1986(1)1990 1992(1)1993 1995(1)1998 {;
u $data/pnad/sector-occupation-comcart/c-withinbetween-`year'.dta, clear;
collapse (mean) wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond
oowithin oobetween oocond soowithin soobetween soocond 
b_indhigh b_indscoll b_indgrad 
b_indchild b_indyouth b_indadol b_indnasc b_indearly b_indpeak b_indlate b_indretir b_indfem
se_indhigh se_indscoll se_indgrad
se_indchild se_indyouth se_indadol se_indnasc se_indearly se_indpeak se_indlate se_indretir se_indfem
regR2 regobs
, by(year) fast;
sa $data/pnad/sector-occupation-comcart/c-withinbetween-`year'.dta,replace;
};


