#delimit;

clear;
clear matrix;
set more off;
capture log close; 


****************;
* Descriptives *;
****************;

foreach year of numlist 1986(1)1990 1992(1)1993 1995(1)1998 {;

use $input/pnad`year'pes_comp81_likerais.dta, clear;

* Define sample;

do $dofiles/routines/pnad-samplecond.do;

* Education cells;

gen educ=1;
replace educ=2 if indhigh==1;
replace educ=3 if indscoll==1;
replace educ=4 if indgrad==1; 

* Employment shares and mean wages;

egen tot_emp=sum(employ);
egen occ_emp=sum(employ),by(occup);
egen ind_emp=sum(employ),by(firm_subsibge);
egen edu_emp=sum(employ),by(educ);

gen occ_empsh=occ_emp/tot_emp;
gen ind_empsh=ind_emp/tot_emp;
gen edu_empsh=edu_emp/tot_emp;

* Mean log wages;

egen mn_lwageyr=mean(lwageyr);
egen occ_mn_lwageyr=mean(lwageyr),by(occup);
egen ind_mn_lwageyr=mean(lwageyr),by(firm_subsibge);
egen edu_mn_lwageyr=mean(lwageyr),by(educ);

gen occ_relwge=occ_mn_lwageyr-mn_lwageyr;
gen ind_relwge=ind_mn_lwageyr-mn_lwageyr;
gen edu_relwge=edu_mn_lwageyr-mn_lwageyr;

* Standard deviation log wage;

egen var_lwageyr=sd(lwageyr);
replace var_lwageyr=var_lwageyr*var_lwageyr;

* Save data;

tempfile sjrtemp;
sa `sjrtemp';

* Save collapsed data;

u `sjrtemp', clear;
collapse (mean) occ_empsh occ_relwge , by(occup) fast;
gen year=`year';
so occup year;
sa $data/pnad/prepdata/o-descrip`year'.dta,replace;
u `sjrtemp', clear;
collapse (mean) ind_empsh ind_relwge , by(firm_subsibge) fast;
gen year=`year';
so firm_subsibge year;
sa $data/pnad/prepdata/i-descrip`year'.dta,replace;
u `sjrtemp', clear;
collapse (mean) edu_empsh edu_relwge , by(educ) fast;
gen year=`year';
so educ year;
sa $data/pnad/prepdata/e-descrip`year'.dta,replace;
u `sjrtemp', clear;
collapse (mean) mn_lwageyr var_lwageyr, fast;
gen year=`year';
so year;
sa $data/pnad/prepdata/descrip`year'.dta,replace;

};

*****************************************;
* Append descriptives datasets together *;
*****************************************;

#delimit;
u $data/pnad/prepdata/o-descrip1986.dta, clear;
foreach year of numlist 1987(1)1990 1992(1)1993 1995(1)1998 {;
append using $data/pnad/prepdata/o-descrip`year'.dta;
};
so occup year;
sa $data/pnad/prepdata/o-descrip-all.dta,replace;

u $data/pnad/prepdata/i-descrip1986.dta, clear;
foreach year of numlist 1987(1)1990 1992(1)1993 1995(1)1998 {;
append using $data/pnad/prepdata/i-descrip`year'.dta;
};
so firm_subsibge year;
sa $data/pnad/prepdata/i-descrip-all.dta,replace;

u $data/pnad/prepdata/e-descrip1986.dta, clear;
foreach year of numlist 1987(1)1990 1992(1)1993 1995(1)1998 {;
append using $data/pnad/prepdata/e-descrip`year'.dta;
};
so educ year;
sa $data/pnad/prepdata/e-descrip-all.dta,replace;

u $data/pnad/prepdata/descrip1986.dta, clear;
foreach year of numlist 1987(1)1990 1992(1)1993 1995(1)1998 {;
append using $data/pnad/prepdata/descrip`year'.dta;
};
so year;
sa $data/pnad/prepdata/descrip-all.dta,replace;

**********;
* Tables *;
**********;

capture log close; 
log using $logs/descriptives.log,replace; 

***************;
* Occupations *;
***************;
#delimit;
u $data/pnad/prepdata/o-descrip-all.dta,clear;

* Occupation table;

* 1990;

table occup if year==1990, c(mean occ_empsh mean occ_relwge);

* 1995;

table occup if year==1995, c(mean occ_empsh mean occ_relwge);

* Occupation figure;

lab var occ_empsh "Employment share";

twoway (scatter occ_empsh year if occup==1, c(l) msymbol(i) lpattern(solid) lcolor(black) lwidth(thick) yaxis(1))
(scatter occ_empsh year if occup==2, c(l) msymbol(i) lpattern(solid) lcolor(gs12) lwidth(thick) yaxis(1))
(scatter occ_empsh year if occup==3, c(l) msymbol(i) lpattern(dash) lcolor(black) lwidth(thick) yaxis(1))
(scatter occ_empsh year if occup==4, c(l) msymbol(i) lpattern(dash) lcolor(gs12) lwidth(thick) yaxis(2))
(scatter occ_empsh year if occup==5, c(l) msymbol(i) lpattern(solid) lcolor(black) lwidth(medium) yaxis(1))
,
graphregion(fcolor(gs16))
legend(lab(1 "Professional & Managerial") lab(2 "Skilled White Collar") lab(3 "Unskilled White Collar") lab(4 "Skilled Blue Collar") lab(5 "Unskilled Blue Collar") size(small))
title(Shares of Occupations in Total Employment)
xtitle(Year)
note("Note: Skilled blue collar share shown on right axis scale.")
saving($grph/occ_empsh,replace)
;

************;
* Industry *;
************;

u $data/pnad/prepdata/i-descrip-all.dta,clear;

* Industry table 1990;

table firm_subsibge if year==1990, c(mean ind_empsh mean ind_relwge);

* Industry table 1995;

table firm_subsibge if year==1995, c(mean ind_empsh mean ind_relwge);

* Industry figures;

lab var ind_empsh "Employment share";

twoway (scatter ind_empsh year if firm_subsibge==13, c(l) msymbol(i) lpattern(solid) lcolor(black) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==11, c(l) msymbol(i) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==10, c(l) msymbol(i) lpattern(dash) lcolor(black) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==3, c(l) msymbol(i) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Food, Beverages & Alcohol") lab(2 "Apparel & Textiles") lab(3 "Chemical & Pharmaceuticals") lab(4 "Metallic Products") size(small))
xtitle(Year)
saving($grph/ind_empsh1,replace)
;

twoway (scatter ind_empsh year if firm_subsibge==2, c(l) msymbol(i) lpattern(solid) lcolor(black) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==4, c(l) msymbol(i) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==5, c(l) msymbol(i) lpattern(dash) lcolor(black) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==6, c(l) msymbol(i) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Non-metallic Minerals") lab(2 "Machinery & Equipment") lab(3 "Electrical & Telecommunications") lab(4 "Transport Equipment") size(small))
title(Shares of Industries in Total Employment)
xtitle(Year)
saving($grph/ind_empsh2,replace)
;

twoway (scatter ind_empsh year if firm_subsibge==7, c(l) msymbol(i) lpattern(solid) lcolor(black) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==8, c(l) msymbol(i) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==9, c(l) msymbol(i) lpattern(dash) lcolor(black) lwidth(thick))
(scatter ind_empsh year if firm_subsibge==12, c(l) msymbol(i) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Wood Products") lab(2 "Paper and Publishing") lab(3 "Rubber & Tobacco") lab(4 "Footwear") size(small))
title(Shares of Industries in Total Employment)
xtitle(Year)
saving($grph/ind_empsh3,replace)
;

gr combine "$grph/ind_empsh1.gph"
"$grph/ind_empsh2.gph"
"$grph/ind_empsh3.gph"
,
graphregion(fcolor(gs16))
iscale(0.4)
title(Shares of Industries in Total Employment)
saving($grph/ind_empsh_all,replace)
;

*************;
* Aggregate *;
*************;

#delimit;
u $data/pnad/prepdata/descrip-all.dta,clear;

lab var mn_lwageyr "Mean log wage (BRL deflated to 9/2012)";
lab var var_lwageyr "Variance log wage (BRL deflated to 9/2012)";

* Figure for presentation;

twoway (scatter mn_lwageyr year , c(l) msymbol(i) lpattern(solid) lcolor(blue) lwidth(thick) yaxis(1))
(scatter var_lwageyr year , c(l) msymbol(i) lpattern(dash) lcolor(red) lwidth(thick) yaxis(2))
,
graphregion(fcolor(gs16))
legend(lab(1 "Mean log wage (left scale)") lab(2 "Variance log wage (right scale)") cols(2) rows(1) size(small))
xtitle(Year)
xlabel(1986 1990 1995 1998)
saving($grph/mn_var_lwageyr,replace)
;

graph export $grph/mn_var_lwageyr.eps, as(eps) replace;

* Figure for paper;

twoway (scatter mn_lwageyr year , c(l) msymbol(i) lpattern(solid) lcolor(black) lwidth(thick) yaxis(1))
(scatter var_lwageyr year , c(l) msymbol(i) lpattern(solid) lcolor(gs12) lwidth(thick) yaxis(2))
,
graphregion(fcolor(gs16))
legend(lab(1 "Mean log wage (left scale)") lab(2 "Variance log wage (right scale)") cols(2) rows(1) size(small))
xtitle(Year)
xlabel(1986 1990 1995 1998)
saving($grph/mn_var_lwageyr_bw,replace)
;

log close;


