#delimit;

clear;
clear matrix;
set more off;

capture log close; 
log using $logs/soanalysis-comcart.log, replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/pnad/sector-occupation-comcart/withinbetween-1986.dta, clear;
foreach year of numlist 1987(1)1990 1992(1)1993 1995(1)1998 {;
append using $data/pnad/sector-occupation-comcart/withinbetween-`year'.dta;
};

lab var swithin     "within sectors log wage component";
lab var sbetween    "between sectors log wage component";
lab var stotal      "total log wage component (across sectors)";

lab var owithin     "within occupations log wage component";
lab var obetween    "between occupations log wage component";
lab var ototal      "total log wage component (across occupations)";

lab var sowithin    "within sector-occupations log wage component";
lab var sobetween   "between sector-occupations log wage component";
lab var sototal     "total log wage component (across sector-occupations)";

lab var oowithin    "within detailed occupations log wage component";
lab var oobetween   "between detailed occupations log wage component";
lab var oototal     "total log wage component (across detailed occupations)";

lab var soowithin   "within sector-detailed-occupations log wage component";
lab var soobetween  "between sector-detailed-occupations log wage component";
lab var soototal    "total log wage component (across sector-detailed-occupations)";

lab var lwageyr9050 "Ratio 90:50 percentiles of log wages";
lab var lwageyr5010 "Ratio 50:10 percentiles of log wages";

lab var fswithin9050    "Ratio 90:50 percentiles of sector within component";
lab var fswithin5010    "Ratio 50:10 percentiles of sector within component";
lab var fsbetween9050   "Ratio 90:50 percentiles of sector between component";
lab var fsbetween5010   "Ratio 50:10 percentiles of sector between component";

lab var fowithin9050    "Ratio 90:50 percentiles of occupation within component";
lab var fowithin5010    "Ratio 50:10 percentiles of occupation within component";
lab var fobetween9050   "Ratio 90:50 percentiles of occupation between component";
lab var fobetween5010   "Ratio 50:10 percentiles of occupation between component";

lab var fsowithin9050   "Ratio 90:50 percentiles of sector-occupation within component";
lab var fsowithin5010   "Ratio 50:10 percentiles of sector-occupation within component";
lab var fsobetween9050  "Ratio 90:50 percentiles of sector-occupation between component";
lab var fsobetween5010  "Ratio 50:10 percentiles of sector-occupation between component";

local outvar="year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
oowithin oobetween oototal soowithin soobetween soototal;
sort year;
sa $data/pnad/sector-occupation-comcart/withinbetween-all.dta, replace;
outsheet `outvar' using $data/pnad/sector-occupation-comcart/univ-sectoroccupation-all.csv, comma names replace; 

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

gen sdtotal=(stotal^0.5);

local vars1="swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";
local vars2="oowithin oobetween oototal soowithin soobetween soototal";
local vars3="lwageyr9050 lwageyr5010";

foreach var of varlist `vars1' `vars2' `vars3' sdtotal {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'95;
};   

***********************************;
**** Baseline Tables for Paper ****;
***********************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;
gen sh_oowithin=oowithin/oototal;
gen sh_soowithin=soowithin/soototal;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal oowithin oobetween oototal soowithin soobetween soototal sdtotal {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
gen d_`var'95=(`var'98-`var'95)/`var'95; 
};

* Increase in variance and standard deviation of wages 1986-1995;

su d_stotal86 d_sdtotal86;

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_stotal86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ototal86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_sototal86;
gen cnt_oowithin86=(sh_oowithin86*d_oowithin86)/d_oototal86;
gen cnt_soowithin86=(sh_soowithin86*d_soowithin86)/d_soototal86;

gen cnt_swithin95=(sh_swithin95*d_swithin95)/d_stotal95;
gen cnt_owithin95=(sh_owithin95*d_owithin95)/d_ototal95;
gen cnt_sowithin95=(sh_sowithin95*d_sowithin95)/d_sototal95;
gen cnt_oowithin95=(sh_oowithin95*d_oowithin95)/d_oototal95;
gen cnt_soowithin95=(sh_soowithin95*d_soowithin95)/d_soototal95;

* Level within contributions in 1990;

format sh_swithin sh_owithin sh_sowithin %10.3f;
table data if year==1990, c(mean sh_swithin mean sh_owithin mean sh_sowithin);

* Sector contributions 1986-1995;

format d_stotal86 cnt_swithin86 sh_swithin86 d_swithin86 d_sbetween86 %10.3f;
table data if year==1995, c(mean d_stotal86 mean cnt_swithin86 mean sh_swithin86 mean d_swithin86 mean d_sbetween86);

* Occupation contributions 1986-1995;

format d_ototal86 cnt_owithin86 sh_owithin86 d_owithin86 d_obetween86 %10.3f;
table data if year==1995, c(mean d_ototal86 mean cnt_owithin86 mean sh_owithin86 mean d_owithin86 mean d_obetween86);

* Sector-occupation contributions 1986-1995;

format d_sototal86 cnt_sowithin86 sh_sowithin86 d_sowithin86 d_sobetween86 %10.3f;
table data if year==1995, c(mean d_sototal86 mean cnt_sowithin86 mean sh_sowithin86 mean d_sowithin86 mean d_sobetween86);

**********************************************************;
**** Robustness Tables 1986-1995 for Paper            ****;
**** More Detailed Occupations and Sector-Occupations ****;
**********************************************************;

* Level within contributions in 1990;

format sh_oowithin sh_soowithin %10.3f;
table data if year==1990, c(mean sh_oowithin mean sh_soowithin);

* Detailed Occupation contributions 1986-1995;

format d_oototal86 cnt_oowithin86 sh_oowithin86 d_oowithin86 d_oobetween86 %10.3f;
table data if year==1995, c(mean d_oototal86 mean cnt_oowithin86 mean sh_oowithin86 mean d_oowithin86 mean d_oobetween86);

* Sector-Detailed-Occupation contributions 1986-1995;

format d_soototal86 cnt_soowithin86 sh_soowithin86 d_soowithin86 d_soobetween86 %10.3f;
table data if year==1995, c(mean d_soototal86 mean cnt_soowithin86 mean sh_soowithin86 mean d_soowithin86 mean d_soobetween86);

***********************************************;
**** Robustness Tables 1995-1998 for Paper ****;
**** More Detailed Occupations and Sectors ****;
***********************************************;

* Level within contributions in 1995;

format sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin %10.3f;
table data if year==1995, c(mean sh_swithin mean sh_owithin mean sh_sowithin mean sh_oowithin mean sh_soowithin);

* Sector contributions 1995-1998;

format d_stotal95 cnt_swithin95 sh_swithin95 d_swithin95 d_sbetween95 %10.3f;
table data if year==1995, c(mean d_stotal95 mean cnt_swithin95 mean sh_swithin95 mean d_swithin95 mean d_sbetween95);

* Occupation contributions 1995-1998;

format d_ototal95 cnt_owithin95 sh_owithin95 d_owithin95 d_obetween95 %10.3f;
table data if year==1995, c(mean d_ototal95 mean cnt_owithin95 mean sh_owithin95 mean d_owithin95 mean d_obetween95);

* Sector-occupation contributions 1995-1998;

format d_sototal95 cnt_sowithin95 sh_sowithin95 d_sowithin95 d_sobetween95 %10.3f;
table data if year==1995, c(mean d_sototal95 mean cnt_sowithin95 mean sh_sowithin95 mean d_sowithin95 mean d_sobetween95);

* Detailed Occupation contributions 1995-1998;

format d_oototal95 cnt_oowithin95 sh_oowithin95 d_oowithin95 d_oobetween95 %10.3f;
table data if year==1995, c(mean d_oototal95 mean cnt_oowithin95 mean sh_oowithin95 mean d_oowithin95 mean d_oobetween95);

* Sector-Detailed-Occupation contributions 1995-1998;

format d_soototal95 cnt_soowithin95 sh_soowithin95 d_soowithin95 d_soobetween95 %10.3f;
table data if year==1995, c(mean d_soototal95 mean cnt_soowithin95 mean sh_soowithin95 mean d_soowithin95 mean d_soobetween95);

***************************;
**** Figures for paper ****;
***************************;

* Levels;

twoway 
(scatter stotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter swithin year , msymbol(i) c(l) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter owithin year , msymbol(i) c(l) lpattern(dash) lcolor(black) lwidth(thick))
(scatter sowithin year , msymbol(i) c(l) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within Sector") lab(3 "Within Occupation") lab(4 "Within Sector-Occupation"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Variance log wage)
saving($grphcc/sector-occupation/uncond_level_all_bw,replace)
;

twoway (scatter istotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector") lab(3 "Between sector"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Variance log wage, margin(small))
title("Panel A: Sectors")
saving($grphcc/sector-occupation/sector,replace)
;

twoway (scatter iototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within occupation") lab(3 "Between occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Variance log wage, margin(small))
title("Panel B: Occupations")
saving($grphcc/sector-occupation/occupation,replace)
;

twoway (scatter isototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector-occupation") lab(3 "Between sector-occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Variance log wage, margin(small))
title("Panel C: Sector-occupations")
saving($grphcc/sector-occupation/sectoroccupation,replace)
;

#delimit;
graph combine "$grphcc/sector-occupation/sector.gph"
"$grphcc/sector-occupation/occupation.gph"
"$grphcc/sector-occupation/sectoroccupation.gph"
 ,
graphregion(fcolor(gs16))
iscale(0.4)

saving("$grphcc/sector-occupation/so_index.gph",replace)
;

graph export $grphcc/sector-occupation/so_index.eps, as(eps) replace;

**********************************;
**** Figures for presentation ****;
**********************************;

* Levels;

#delimit;
twoway 
(scatter stotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter swithin year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter owithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter sowithin year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within Sector") lab(3 "Within Occupation") lab(4 "Within Sector-Occupation"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Log Wage Dispersion)
saving($grphcc/sector-occupation/uncond_level_all,replace)
;

twoway 
(scatter istotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector") lab(3 "Between sector"))
xlabel(1986 1990 1995 1998)
ylabel(0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title(Log Wage Dispersion (Sectors))
saving($grphcc/sector-occupation/u-i-sector,replace)
;

twoway (scatter iototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within occupation") lab(3 "Between occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title(Log Wage Dispersion (Occupations))
saving($grphcc/sector-occupation/u-i-occupation,replace)
;

twoway (scatter isototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector-occupation") lab(3 "Between sector-occupation"))
xlabel(1986 1990 1995 1998)
ylabel(0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title(Log Wage Dispersion (Sector-Occupations))
saving($grphcc/sector-occupation/u-i-sectoroccupation,replace)
;

********************************************;
**** Robustness to detailed occupations ****;
********************************************;

* Levels;

twoway 
(scatter stotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter swithin year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter oowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter soowithin year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within Sector") lab(3 "Within Detail Occ") lab(4 "Within Sector-Detail-Occ"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Log Wage Dispersion)
saving($grphcc/sector-occupation/uncond_level_all_det,replace)
;

twoway (scatter ioototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter ioowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter ioobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within Detail Occ") lab(3 "Between Detail Occ"))
xlabel(1986 1990 1995 1998)
ylabel(0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title(Log Wage Dispersion (Detailed Occ))
saving($grphcc/sector-occupation/u-i-occupation-det,replace)
;

twoway (scatter isoototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter isoowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isoobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within Sector-Detail-Occ") lab(3 "Between Sector-Detail-Occ"))
xlabel(1986 1990 1995 1998)
ylabel(0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title(Log Wage Dispersion (Sector-Occupations))
saving($grphcc/sector-occupation/u-i-sectoroccupation-det,replace)
;

**********************;
**** Polarization ****;
**********************;

twoway (scatter ilwageyr9050 year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter ilwageyr5010 year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Log Wage 9050") lab(2 "Log Wage5010"))
xlabel(1986 1990 1995 1998)
xtitle(Year)
ytitle(Index (1986=0))
title(Log Wage Polarization)
saving($grphcc/sector-occupation/u-i-lwageyr-9010,replace)
;

log close;
