#delimit;

clear;
clear matrix;
set more off;
capture log close; 

log using $logs/soanova_ramo.log, replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach year of numlist 1995(1)1998 {;

use $input/pnad`year'pes_comp81_likerais.dta, clear;

* Drop observations with problematic firm_ramo codes;

drop if firm_ramo<=0;
drop if firm_ramo==.;

* Define sample;

do $dofiles/routines/pnad-samplecond.do;

***************;
**** Setup ****;
***************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

* categorical variables;

gen temp1=firm_ramo;
tostring temp1,replace;
gen temp2=cbogrp;
tostring temp2, replace;
gen temp3=temp1+"AA"+temp2;
encode temp3, gen(secoccup);
drop temp1 temp2 temp3;

* Codebook;

codebook cbogrp;
codebook firm_ramo;
codebook secoccup;

* within/between decomposition for sectors;
areg lwageyr, abs(firm_ramo);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sbetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen swithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen stotal = swithin + sbetween;

* within/between decomposition for occupations;
areg lwageyr, abs(cbogrp);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen obetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen owithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen ototal = owithin + obetween;

areg lwageyr, abs(secoccup);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen sowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen sototal = sowithin + sobetween;

*************;
* Save Data *;
*************;

collapse (mean) swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal, fast;
gen year=`year';

sa $data/pnad/sector-occupation/withinbetween-`year'-alt.dta,replace;

};

log close;


