
#delimit;

clear;
clear matrix;
set mem 4000m;
set matsize 10000;
set more off;
capture log close;
graph set print logo off;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

********************************;
**** Clean nationality data ****;
********************************;
/*;
10 : Brazilian;
20 : Naturalized Brazilian;
21 : Latin American n.e.c.;
30 : German;
31 : European n.e.c.;
34 : Foreign nationality n.e.c.;
35 : Spanish;
36 : U.S.;
39 : Italian; 
41 : Japanese;
42 : Asian n.e.c.; 
45 : Portuguese;
*/;

foreach yr of numlist 1986(1)1998 {;
u $input/workers-template-`yr'-nacl.dta;

gen forworker=0;
replace forworker=1 if nacionalidad>20&nacionalidad!=.;
tab forworker;

gen useujap=0;
replace useujap=1 if nacionalidad==30;
replace useujap=1 if nacionalidad==31;
replace useujap=1 if nacionalidad==35;
replace useujap=1 if nacionalidad==36;
replace useujap=1 if nacionalidad==39;
replace useujap=1 if nacionalidad==41;
replace useujap=1 if nacionalidad==45;
tab useujap;

drop identificad ano nacionalidad;
so pis;
sa $data/nationality/workers-template-`yr'-nacl-clean.dta,replace;
};

**********************************************************;
**** Create nationality measures at meso region level ****;
**********************************************************;

#delimit;
foreach yr of numlist 1986(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $input/workers-template-`yr'-nacl.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
so cnpj_radic pis;

gen mesotot=1;

gen mesofor=0;
replace mesofor=1 if nacionalidad>20&nacionalidad!=.;

gen mesoUEJ=0;
replace mesoUEJ=1 if nacionalidad==30;
replace mesoUEJ=1 if nacionalidad==31;
replace mesoUEJ=1 if nacionalidad==35;
replace mesoUEJ=1 if nacionalidad==36;
replace mesoUEJ=1 if nacionalidad==39;
replace mesoUEJ=1 if nacionalidad==41;
replace mesoUEJ=1 if nacionalidad==45;

gen mesoforshare=mesofor;
gen mesoUEJshare=mesoUEJ;

keep pis meso mesotot mesofor mesoUEJ mesoforshare mesoUEJshare;
collapse (sum) mesotot mesofor mesoUEJ (mean) mesoforshare mesoUEJshare , by(meso) fast;
gen year=`yr';

lab var mesotot "Total number of workers in meso region";
lab var mesofor "Total number of foreign workers in meso region";
lab var mesoforshare "Share of foreign workers in meso region";
lab var mesoUEJ "Total number of US/EU/JAP workers in meso region";
lab var mesoUEJshare "Share of US/EU/JAP workers in meso region";

so meso year;
sa $data/nationality/meso-for-workers-`yr'.dta, replace;

};

u $data/nationality/meso-for-workers-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/nationality/meso-for-workers-`yr'.dta;
};
so meso year;
sa $data/nationality/meso-for-workers-all.dta, replace;

