
#delimit;

clear;
clear matrix;
set mem 4000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

****************;
* Descriptives *;
****************;

foreach yr of numlist 1986(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

* Education cells;

gen educ=1;
replace educ=2 if indhigh==1;
replace educ=3 if indscoll==1;
replace educ=4 if indgrad==1; 

* Employment shares and mean wages;

egen tot_emp=sum(employ);
egen occ_emp=sum(employ),by(occup);
egen ind_emp=sum(employ),by(firm_subsibge);
egen edu_emp=sum(employ),by(educ);

gen occ_empsh=occ_emp/tot_emp;
gen ind_empsh=ind_emp/tot_emp;
gen edu_empsh=edu_emp/tot_emp;

* Mean log wages;

egen mn_lwageyr=mean(lwageyr);
egen occ_mn_lwageyr=mean(lwageyr),by(occup);
egen ind_mn_lwageyr=mean(lwageyr),by(firm_subsibge);
egen edu_mn_lwageyr=mean(lwageyr),by(educ);

gen occ_relwge=occ_mn_lwageyr-mn_lwageyr;
gen ind_relwge=ind_mn_lwageyr-mn_lwageyr;
gen edu_relwge=edu_mn_lwageyr-mn_lwageyr;

* Standard deviation log wage;

egen var_lwageyr=sd(lwageyr);
replace var_lwageyr=var_lwageyr*var_lwageyr;

* Save data;

sa $data/tmp/sjrtemp.dta,replace;

* Save collapsed data;

u $data/tmp/sjrtemp.dta, clear;
collapse (mean) occ_empsh occ_relwge , by(occup) fast;
gen year=`yr';
so occup year;
sa $data/prepdata/o-descrip`yr'.dta,replace;
u $data/tmp/sjrtemp.dta, clear;
collapse (mean) ind_empsh ind_relwge , by(firm_subsibge) fast;
gen year=`yr';
so firm_subsibge year;
sa $data/prepdata/i-descrip`yr'.dta,replace;
u $data/tmp/sjrtemp.dta, clear;
collapse (mean) edu_empsh edu_relwge , by(educ) fast;
gen year=`yr';
so educ year;
sa $data/prepdata/e-descrip`yr'.dta,replace;
u /data/tmp/sjrtemp.dta, clear;
collapse (mean) mn_lwageyr var_lwageyr, fast;
gen year=`yr';
so year;
sa $data/prepdata/descrip`yr'.dta,replace;

};

*****************************************;
* Append descriptives datasets together *;
*****************************************;

#delimit;
u $data/prepdata/o-descrip1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/prepdata/o-descrip`yr'.dta;
};
so occup year;
sa $data/prepdata/o-descrip-all.dta,replace;

u $data/prepdata/i-descrip1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/prepdata/i-descrip`yr'.dta;
};
so firm_subsibge year;
sa $data/prepdata/i-descrip-all.dta,replace;

u $data/prepdata/e-descrip1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/prepdata/e-descrip`yr'.dta;
};
so educ year;
sa $data/prepdata/e-descrip-all.dta,replace;

u $data/prepdata/descrip1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/prepdata/descrip`yr'.dta;
};
so year;
sa $data/prepdata/descrip-all.dta,replace;

**********;
* Tables *;
**********;

capture log close;
log using $logs/prepdata/descriptives.log,replace; 

***************;
* Occupations *;
***************;
#delimit;
u $data/prepdata/o-descrip-all.dta,clear;

**** Table A1 of the paper;
**** Occupation table for 1994;
**** Columns (1) and (2);

table occup if year==1994, c(mean occ_empsh mean occ_relwge);

************;
* Industry *;
************;

u $data/prepdata/i-descrip-all.dta,clear;

**** Table A2 of the paper;
**** Industry table for 1994;
**** Columns (1) and (2);

table firm_subsibge if year==1994, c(mean ind_empsh mean ind_relwge);

log close;







