
#delimit;

*****************************************************************************;
**** This file constructs an occupation-industry-year employment dataset ****;
**** and computes measures of the dispersion of employment               ****;
*****************************************************************************;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/prepdata/dispemp.log, replace;

foreach yr of numlist 1986(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

* Save data;

sa $data/tmp/sjrtemp.dta,replace;

* Generate an occupation-industry dataset for each year;

collapse (sum) employ , by(firm_subsibge occup) fast;
gen year=`yr';
so firm_subsibge occup year;
sa $data/prepdata/emp-ind-occup-`yr'.dta,replace;
ren firm_subsibge industry;
outsheet industry occup employ year using $data/prepdata/emp-ind-occup-`yr'.csv , names comma replace;

********************;
* Collapse to Firm *;
********************;

clear;
u $data/tmp/sjrtemp.dta; 
collapse (sum) employ , by(cnpj_radic firm_subsibge) fast;
gen lemploy=ln(employ);
egen sd_lemp=sd(lemploy), by(firm_subsibge);
collapse (mean) sd_lemp, by(firm_subsibge);
gen year=`yr';
lab var sd_lemp "Standard Deviation Log Employment Across Firms Within Industries";

*************;
* Save Data *;
*************;

so firm_subsibge;
sa $data/prepdata/sd_lemp-`yr'.dta,replace;

};

*************************************************;
* Merge Employment Dispersion Datasets Together *;
*************************************************;

u $data/prepdata/sd_lemp-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/prepdata/sd_lemp-`yr'.dta;
};
so firm_subsibge year;
sa $data/prepdata/sd_lemp-all.dta, replace;

log close;
