
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
set scheme s1mono;
capture log close;

*************************************************************************;
**** Robustness test decomposing overall wage inequality into within ****;
**** and between sector-occupation components controlling for        ****; 
**** worker observables, industry and region                         ****;
**** Generates the graphs in Figure H7 of the Online Supplement      ****;
*************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global graphs="/home/sjredding/himr-restud/stata/graphs";

log using $logs/sector-occupation/csoanalysis_regioncontrol.log,replace;

u $data/sector-occupation/c-region-indcoeffs-1986.dta;
foreach yr of numlist 1987(1)1998 {;
merge 1:1 firm_subsibge year using $data/sector-occupation/c-region-indcoeffs-`yr'.dta;
tab _m;
drop _m;
};

so firm_subsibge year;
twoway (scatter fclwageyrind year if firm_subsibge==2, c(l) msymbol(i) lpattern(solid) lwidth(thick) lcolor(black))
(scatter fclwageyrind year if firm_subsibge==3, c(l) msymbol(i) lpattern(solid) lwidth(thick) lcolor(gray))
(scatter fclwageyrind year if firm_subsibge==4, c(l) msymbol(i) lpattern(dash) lwidth(thick) lcolor(black))
(scatter fclwageyrind year if firm_subsibge==5, c(l) msymbol(i) lpattern(dash) lwidth(thick) lcolor(gray))
,
legend(lab(1 "Industry 2") lab(2 "Industry 3") lab(3 "Industry 4") lab(4 "Industry 5"))
ytitle(Industry-year wage fixed effect)
xtitle(Year)
title(Panel A)
saving("$graphs/sector-occupation/cond-ind-yr-fes-A.gph",replace)
;

twoway (scatter fclwageyrind year if firm_subsibge==6, c(l) msymbol(i) lpattern(solid) lwidth(thick) lcolor(black))
(scatter fclwageyrind year if firm_subsibge==7, c(l) msymbol(i) lpattern(solid) lwidth(thick) lcolor(gray))
(scatter fclwageyrind year if firm_subsibge==8, c(l) msymbol(i) lpattern(dash) lwidth(thick) lcolor(black))
(scatter fclwageyrind year if firm_subsibge==9, c(l) msymbol(i) lpattern(dash) lwidth(thick) lcolor(gray))
,
legend(lab(1 "Industry 6") lab(2 "Industry 7") lab(3 "Industry 8") lab(4 "Industry 9"))
ytitle(Industry-year wage fixed effect)
xtitle(Year)
title(Panel B)
saving("$graphs/sector-occupation/cond-ind-yr-fes-B.gph",replace)
;

twoway (scatter fclwageyrind year if firm_subsibge==10, c(l) msymbol(i) lpattern(solid) lwidth(thick) lcolor(black))
(scatter fclwageyrind year if firm_subsibge==11, c(l) msymbol(i) lpattern(solid) lwidth(thick) lcolor(gray))
(scatter fclwageyrind year if firm_subsibge==12, c(l) msymbol(i) lpattern(dash) lwidth(thick) lcolor(black))
(scatter fclwageyrind year if firm_subsibge==13, c(l) msymbol(i) lpattern(dash) lwidth(thick) lcolor(gray))
,
legend(lab(1 "Industry 10") lab(2 "Industry 11") lab(3 "Industry 12") lab(4 "Industry 13"))
ytitle(Industry-year wage fixed effect)
xtitle(Year)
title(Panel C)
saving("$graphs/sector-occupation/cond-ind-yr-fes-C.gph",replace)
;

gr combine "$graphs/sector-occupation/cond-ind-yr-fes-A.gph" "$graphs/sector-occupation/cond-ind-yr-fes-B.gph"
"$graphs/sector-occupation/cond-ind-yr-fes-C.gph" ,
iscale(0.4)
saving("$graphs/sector-occupation/cond-ind-yr-fes-ALL.gph",replace)
;

graph export "$graphs/sector-occupation/cond-ind-yr-fes-ALL.eps", as(eps) replace;

log close;

