
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

***************************************************************;
**** This file constructs datasets for the robustness test ****;
**** using more disaggregated education categories in      ****;
**** the decomposition of residual wage inequality         ****;
**** into within and between sector-occupation components  ****;
**** in Section H7 and Table H4 in the online supplement   ****; 
*******************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/csoanova_educ.log,replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach yr of numlist 1986(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

* Merge new education data;

so pis identificad;
merge 1:1 pis identificad using $input/workers-template-`yr'-educ.dta;
tab _m;
if _m==2 {;
stop;
};
drop _m;
so cnpj_radic pis;

drop indhigh indscoll indgrad;

foreach num of numlist 1(1)9 {;
gen educ`num'=0;
replace educ`num'=1 if grau_instr==`num';
};

*********************;
* Setup and Loop    *;
*********************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educvars="educ2 educ3 educ4 educ5 educ6 educ7 educ8 educ9";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* Categorical variables;

egen secoccup = group(firm_subsibge occup);
egen soo = group(firm_subsibge cbogrp);

* Single Mincer regression;
reg lwageyr `demog' `educvars' tenure2-tenure5 , robust;
predict clwageyr if e(sample), res;
predict flwageyr if e(sample), xb;
gen b_educ2=_b[educ2]; 
gen b_educ3=_b[educ3]; 
gen b_educ4=_b[educ4];
gen b_educ5=_b[educ5];
gen b_educ6=_b[educ6];
gen b_educ7=_b[educ7];
gen b_educ8=_b[educ8];
gen b_educ9=_b[educ9];
gen b_tenure2=_b[tenure2];
gen b_tenure3=_b[tenure3];
gen b_tenure4=_b[tenure4];
gen b_tenure5=_b[tenure5];
gen b_indchild=_b[indchild];
gen b_indyouth=_b[indyouth];
gen b_indadol=_b[indadol];
gen b_indnasc=_b[indnasc];
gen b_indearly=_b[indearly];
gen b_indpeak=_b[indpeak];
gen b_indlate=_b[indlate];
gen b_indretir=_b[indretir];
gen b_indfem=_b[indfem];
gen se_educ2=_se[educ2]; 
gen se_educ3=_se[educ3]; 
gen se_educ4=_se[educ4];
gen se_educ5=_se[educ5];
gen se_educ6=_se[educ6];
gen se_educ7=_se[educ7];
gen se_educ8=_se[educ8];
gen se_educ9=_se[educ9];
gen se_tenure2=_se[tenure2];
gen se_tenure3=_se[tenure3];
gen se_tenure4=_se[tenure4];
gen se_tenure5=_se[tenure5];
gen se_indchild=_se[indchild];
gen se_indyouth=_se[indyouth];
gen se_indadol=_se[indadol];
gen se_indnasc=_se[indnasc];
gen se_indearly=_se[indearly];
gen se_indpeak=_se[indpeak];
gen se_indlate=_se[indlate];
gen se_indretir=_se[indretir];
gen se_indfem=_se[indfem];

gen regR2=e(r2);
gen regobs=e(N);

* Raw wage dispersion;
egen temp=sd(lwageyr);
gen wgedisp = temp*temp;
drop temp;

* Observables component;
egen temp=sd(flwageyr);
gen obsdisp = temp*temp;
drop temp;

* within/between decomposition for sectors;
areg clwageyr, abs(firm_subsibge);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sbetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen swithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen scond = swithin + sbetween;

* within/between decomposition for occupations;
areg clwageyr, abs(occup);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen obetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen owithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen ocond = owithin + obetween;

* within/between decompositions for sector-occupations;
areg clwageyr, abs(secoccup);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen sowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen socond = sowithin + sobetween;

* within/between decomposition for detailed occupations;
areg clwageyr, abs(cbogrp);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen oobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen oowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen oocond = oowithin + oobetween;

* within/between decompositions for detailed sector - detailed occupations;
areg clwageyr, abs(soo);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen soobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen soowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen soocond = soowithin + soobetween;

**************;
**** Test ****;
**************;

* Sectors;
gen test=wgedisp-(obsdisp+swithin+sbetween);
replace test=int(10000*test);
su test, d;
drop test;

* Occupations;
gen test=wgedisp-(obsdisp+owithin+obetween);
replace test=int(10000*test);
su test, d;
drop test;

* Sector-occupations;
gen test=wgedisp-(obsdisp+sowithin+sobetween);
replace test=int(10000*test);
su test, d;
drop test;

*************;
* Save Data *;
*************;

gen year=`yr';

collapse (mean) wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond
oowithin oobetween oocond soowithin soobetween soocond 
b_educ2 b_educ3 b_educ4 b_educ5 b_educ6 b_educ7 b_educ8 b_educ9 
b_tenure2 b_tenure3 b_tenure4 b_tenure5 
b_indchild b_indyouth b_indadol b_indnasc b_indearly b_indpeak b_indlate b_indretir b_indfem
se_educ2 se_educ3 se_educ4 se_educ5 se_educ6 se_educ7 se_educ8 se_educ9 
se_tenure2 se_tenure3 se_tenure4 se_tenure5 
se_indchild se_indyouth se_indadol se_indnasc se_indearly se_indpeak se_indlate se_indretir se_indfem
regR2 regobs
, by(year) fast;
so year;
sa $data/sector-occupation/c-educ-withinbetween-`yr'.dta,replace;

};

log close;

