
#delimit;

clear;
clear matrix;
set mem 12000m;
set matsize 10000;
set more off;
capture log close;

*************************************************************************;
**** Robustness test decomposing overall wage inequality into within ****;
**** and between sector-occupation components controlling for        ****; 
**** worker observables, industry and region                         ****;
*************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/csoanova_regioncontrol.log,replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach yr of numlist 1986(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

***************;
**** Setup ****;
***************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

tab meso, gen(rrr);

keep firm_subsibge lwageyr `demog' `educ' tenure* rrr*;

* Mincer regression with industry and region controls;
areg lwageyr `demog' `educ' tenure2-tenure5 rrr*, abs(firm_subsibge) robust;
predict clwageyr if e(sample), res;
predict flwageyr if e(sample), xbd;
predict fclwageyrind, d;

*************;
* Save Data *;
*************;

gen year=`yr';

collapse (mean) fclwageyrind, by(firm_subsibge year) fast;

so firm_subsibge year;
sa $data/sector-occupation/c-region-indcoeffs-`yr'.dta,replace;

};

log close;

