
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

****************************************************************************************;
**** Robustness test by occupation with results of decomposition of wage inequality ****;
**** within sector-occupation-years into within and between-firm                    ****;
**** components                                                                     ****;
****************************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global tables="/home/sjredding/himr-restud/stata/tables";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/uncond/anova/analysis-sector.log,replace;

***********************************************************;
**** Merge within-between decomposition and employment ****; 
**** weights                                           ****;
***********************************************************;

clear;
u $data/uncond/anova/withinbetween-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
tab _m;
drop _m;
sort firm_subsibge occup year;

********************************;
**** AGGREGATES FOR SECTORS ****;
********************************;

replace total = weight_industry * total;
replace within = weight_industry * within;
replace between = weight_industry * between;

collapse (sum) total within between , by(firm_subsibge year) fast;

gen test=total-(within+between);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist total within between {;
gen temp=`var' if year==1986;
egen `var'86=max(temp),by(firm_subsibge);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp),by(firm_subsibge);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_within=within/total;
gen sh_between=between/total;

foreach var of varlist sh_within sh_between {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp),by(firm_subsibge);
drop temp;
gen i`var'=`var'-`var'86;
};

foreach var of varlist total within between {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_within86=(sh_within86*d_within86)/d_total86;
gen cnt_between86=(sh_between86*d_between86)/d_total86;

gen data=1;

**** Robustness test for decomposing the level of wage inequality in 1994;
**** Table H6 of the online supplement (by sector);
**** sh_between : is share of between-firm component;
**** sh_within : is share of within-firm component;

* Level contributions in 1994;

format sh_between sh_within %10.3f;
outsheet firm_subsibge year sh_between sh_within if year==1994 using $tables/anova-sector-level-within-between-1994.csv, comma replace names;

log close;
