
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";
global graphs="/home/sjredding/himr-restud/stata/graphs";

log using $logs/uncond/anova/analysis.log,replace;

***********************************************************;
**** Merge within-between decomposition and employment ****; 
**** weights                                           ****;
***********************************************************;

clear;
u $data/uncond/anova/withinbetween-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
tab _m;
drop _m;
sort firm_subsibge occup year;

gen tot_exp = firm_exp + res_exp;
gen tot_nonexp = firm_nonexp + res_nonexp;

********************;
**** AGGREGATES ****;
********************;

replace total = weight * total;
replace within = weight * within;
replace between = weight * between;

replace tot_exp = weight * tot_exp;
replace firm_exp = weight * firm_exp;
replace res_exp = weight * res_exp;

replace tot_nonexp = weight * tot_nonexp;
replace firm_nonexp = weight * firm_nonexp;
replace res_nonexp = weight * res_nonexp;

replace within_exp = weight * within_exp;
replace within_nonexp = weight * within_nonexp;
replace between_exp = weight * between_exp;

collapse (sum) total within between within_exp within_nonexp between_exp tot_exp firm_exp res_exp tot_nonexp firm_nonexp res_nonexp , by(year) fast;

gen test=total-(within+between);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist total within between within_exp within_nonexp between_exp {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_within=within/total;
gen sh_between=between/total;

foreach var of varlist sh_within sh_between {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
};

foreach var of varlist total within between {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_within86=(sh_within86*d_within86)/d_total86;
gen cnt_between86=(sh_between86*d_between86)/d_total86;

gen data=1;

**** Decomposition of level of within-sector occupation wage inequality 1994;
**** into within and between firm components;

**** Table 2, Column (1), Rows (1)-(2);

format sh_within sh_between %10.3f;
table data if year==1994, c(mean sh_within mean sh_between);

**** Decomposition of changes in within-sector occupation wage inequality 1986-95;
**** into within and between firm components;

**** Table 2, Column (2), Row (1);

format cnt_between86 %10.3f;
table data if year==1995, c(mean cnt_between86);

**** Table 2, Column (2), Row (2);

format cnt_within86 %10.3f;
table data if year==1995, c(mean cnt_within86);

*******************************;
* Decomposition for Exporters *;
*******************************;

gen sh_firm_exp=firm_exp/tot_exp;
gen sh_res_exp=res_exp/tot_exp;

***********************************;
* Decomposition for Non-Exporters *;
***********************************;

gen sh_firm_nonexp=firm_nonexp/tot_nonexp;
gen sh_res_nonexp=res_nonexp/tot_nonexp;

**** Table H8 Online Supplement : Exporters panel; 
**** Column (1);

**** Decomposition of the level within-sector occupation wage inequality in 1994;
**** into the following components; 
**** sh_firm_exp : between-firm component;
**** sh_res_exp : within-firm component;

format sh_firm_exp sh_res_exp %10.3f;
table data if year==1994, c(mean sh_firm_exp mean sh_res_exp);

**** Table H8 Online Supplement : Non-exporters panel; 
**** Column (1);

**** Decomposition of the level within-sector occupation wage inequality in 1994;
**** into the following components; 
**** sh_firm_exp : between-firm component;
**** sh_res_exp : within-firm component;

format sh_firm_nonexp sh_res_nonexp %10.3f;
table data if year==1994, c(mean sh_firm_nonexp mean sh_res_nonexp);

*******************************************************;
**** Decomposition within and between meso regions ****; 
**** with weights                                  ****;
*******************************************************;

clear;
u $data/uncond/anova/withinbetween-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
drop _m;
keep if firm_subsibge>=2 &firm_subsibge<=13;
sort firm_subsibge occup year;

**** Weights;

replace between = weight * between;
replace betweenfirm = weight * betweenfirm;
replace betweenmeso = weight * betweenmeso;

collapse (sum) between betweenfirm betweenmeso, by(year);

gen test=between-(betweenfirm+betweenmeso);
replace test=int(test*10000);
su test, d;
drop test;

**** Tables for Paper;

foreach var of varlist between betweenfirm betweenmeso {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};   

gen sh_bfirm=betweenfirm/between;
gen sh_bmeso=betweenmeso/between;

foreach var of varlist sh_bfirm sh_bmeso {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
};

foreach var of varlist between betweenfirm betweenmeso {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_bfirm86=(sh_bfirm86*d_betweenfirm86)/d_between86;
gen cnt_bmeso86=(sh_bmeso86*d_betweenmeso86)/d_between86;

gen data=1;

**** Footnote 15;
**** Decomposition of variance of level of firm fixed effects in 1994; 
**** into within region and between region;
**** sh_bmeso : between meso region;
**** ssh_bfirm : within meso region (between firm);

format sh_bfirm sh_bmeso %10.3f;
table data if year==1994, c(mean sh_bfirm mean sh_bmeso);

**** Footnote 15;
**** Decomposition of variance of growth of firm fixed effects from 1986-95; 
**** into within region and between region;

**** cnt_bmeso86 : between meso region;

format cnt_bmeso86 %10.3f;
table data if year==1995, c(mean cnt_bmeso86);

**** cnt_bfirm86 : within meso region (between firm);

format cnt_bfirm86 %10.3f;
table data if year==1995, c(mean cnt_bfirm86);

log close;

